@@ -25,6 +25,7 @@
 include("./costanti.php");
 include("./includes/funzioni.php");
 if (!defined("C_CREADB_TIPODB")) include("./includes/costanti.php");
+if (function_exists('ini_set')) @ini_set('opcache.enable',0);
 $pag = "creadb.php";
 $titolo = "HotelDruid: Crea Database";
 
@@ -239,7 +240,7 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('aggiunta_tronca_nomi_tab1','1','-2')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('linee_ripeti_date_tab_mesi','1','25')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('mostra_giorni_tab_mesi','1','SI')");
-esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('colori_tab_mesi','1','#70C6D4,#FFEA00,#FF9900,#FF3115')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('colori_tab_mesi','1','#70C6D4,#FFD800,#FF9900,#FF3115')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_linee_tab2_prenota','1','30')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('nomi_contratti','1','')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_tutte_prenota','1','200')");
@@ -426,7 +427,7 @@ fclose($fileaperto);
 $fileaperto = fopen(C_DATI_PATH."/tema.php","w+");
 fwrite($fileaperto,"<?php
 \$parole_sost = 0;
-\$tema[1] = \"sim\";
+\$tema[1] = \"blu\";
 ?>");
 fclose($fileaperto);
 $fileaperto = fopen(C_DATI_PATH."/versione.php","w+");
