@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -204,7 +204,7 @@ echo mex("Sei sicuro di voler cancellare tutte le regole del tipo 1",$pag)."?
 if ($regola_2 or $regola_2b) {
 if (substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO") {
 $inserire = "NO";
-echo mex("Si deve scegliere la tariffa",$pag).".<br>";
+echo "<br><span class=\"colwarn\">".mex("Si deve scegliere la tariffa",$pag)."</span>.<br><br>";
 } # fine if (substr($tipotariffa,0,7) != "tariffa" or...
 else {
 $regola_esistente = esegui_query("select * from $tableregole where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
@@ -218,28 +218,58 @@ echo mex("La tariffa scelta ha già degli appartamenti associati, cancella la re
 } # fine else if (substr($tipotariffa,0,7) != "tariffa" or...
 if (!$lista_app) {
 $inserire = "NO";
-echo mex("Si deve inserire almeno un appartamento da associare",'unit.php').".<br>";
+echo "<br><span class=\"colwarn\">".mex("Si deve inserire almeno un appartamento da associare",'unit.php')."</span>.<br><br>";
 } # fine if (!$lista_app)
 else {
 $appartamenti = esegui_query("select idappartamenti from $tableappartamenti");
 $num_appartamenti = numlin_query($appartamenti);
+$app_esistente = array();
 for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1 = $num1 + 1) {
 $appartamento = risul_query($appartamenti,$num1,'idappartamenti');
 $app_esistente[$appartamento] = "SI";
 } # fine for $num1
 $vett_app = explode(",",$lista_app);
 $num_app = count($vett_app);
+$num_app_reali = 0;
+$app_trovato = array();
 for ($num1 = 0 ; $num1 < $num_app ; $num1 = $num1 + 1) {
 if ($app_esistente[$vett_app[$num1]] != "SI") {
 $inserire = "NO";
-echo mex("L'appartamento",'unit.php')." ".$vett_app[$num1].mex(" non esiste",$pag).".<br>";
+echo "<br>".mex("L'appartamento",'unit.php')." <b class=\"colwarn\">".$vett_app[$num1]."</b>".mex(" non esiste",$pag).".<br><br>";
 } # fine if ($app_esistente[$appartamento] != "SI")
+else {
+if ($app_trovato[$vett_app[$num1]]) $lista_app = substr(str_replace(",".$vett_app[$num1].",",",",",$lista_app,"),1,-1).",".$vett_app[$num1];
+else $num_app_reali++;
+$app_trovato[$vett_app[$num1]] = 1;
+} # fine else if ($app_esistente[$appartamento] != "SI")
 } # fine for $num1
 } # fine else if (!$lista_app)
+$num_da_assegnare = 1;
+if ($regola_2) {
+$num_da_assegnare = $num_apti;
+if ($num_apti < 1 or $num_apti > $num_appartamenti) $inserire = "NO";
+if ($num_regole_esistente) {
+$regola_2b_esist = risul_query($regola_esistente,0,'motivazione2');
+if (strcmp($regola_2b_esist,"")) {
+$num_regola_2b_esist = explode(",",$regola_2b_esist);
+$num_regola_2b_esist = count($num_regola_2b_esist);
+if ($num_regola_2b_esist < $num_app_reali) $num_app_reali = $num_regola_2b_esist;
+} # fine if if (strcmp($regola_2b_esist,""))
+} # fine if ($num_regole_esistente)
+} # fine if ($regola_2)
+elseif ($num_regole_esistente) {
+$num_da_assegnare = risul_query($regola_esistente,0,'motivazione3');
+if (substr($num_da_assegnare,0,1) == "v") $num_da_assegnare = substr($num_da_assegnare,1);
+} # fine elseif ($num_regole_esistente)
+if ($num_da_assegnare and $num_da_assegnare > $num_app_reali and $inserire != "NO") {
+echo "$num_da_assegnare - $num_app_reali QUI<br>";
+$inserire = "NO";
+echo "<br><span class=\"colwarn\">".mex("Numero di appartamenti",'unit.php')."</span> ".mex("da assegnare troppo alto, supera quello presente nella lista",$pag).".<br><br>";
+} # fine if ($num_da_assegnare and $num_da_assegnare > $num_app_reali and...
 if ($regola_2b) {
 if (!$num_giorni or controlla_num_pos($num_giorni) == "NO") {
 $inserire = "NO";
-echo mex("Si deve inserire il numero di giorni",$pag).".<br>";
+echo "<br><span class=\"colwarn\">".mex("Si deve inserire il numero di giorni",$pag)."</span>.<br><br>";
 } # fine if (!$num_giorni or controlla_num_pos($num_giorni) == "NO")
 if ($ini_fine != "ini" and $ini_fine != "fine") $inserire = "NO";
 if ($ini_fine == "ini") {
@@ -251,20 +281,28 @@ $num_giorni_ini = "NULL";
 $num_giorni_fine = "'$num_giorni'";
 } # fine if ($ini_fine == "fine")
 } # fine if ($regola_2b)
+if ($v_apti != "v") $v_apti = "";
 
 if ($inserire != "NO") {
 if ($num_regole_esistente != 0) {
 if ($regola_2b) esegui_query("update $tableregole set motivazione2 = '$lista_app', iddatainizio = $num_giorni_ini, iddatafine = $num_giorni_fine where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
-else esegui_query("update $tableregole set motivazione = '$lista_app' where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
-echo mex("La regola di assegnazione",$pag)." 2 ".mex("è stata modificata",$pag).".<br>";
+else {
+esegui_query("update $tableregole set motivazione = '$lista_app' where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
+if ($num_apti > 1) esegui_query("update $tableregole set motivazione3 = '$v_apti$num_apti' where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
+else esegui_query("update $tableregole set motivazione3 = NULL where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
+} # fine else if ($regola_2b)
+echo "<br>".mex("La regola di assegnazione",$pag)." 2 ".mex("è stata modificata",$pag).".<br><br>";
 } # fine if ($num_regole_esistente != 0)
 else {
 $idregole = esegui_query("select max(idregole) from $tableregole");
 $idregole = risul_query($idregole,0,0);
 $idregole = $idregole + 1;
 if ($regola_2b) esegui_query("insert into $tableregole (idregole,tariffa_per_app,iddatainizio,motivazione2) values ('$idregole','".aggslashdb($tipotariffa)."','$num_giorni','$lista_app')");
-else esegui_query("insert into $tableregole (idregole,tariffa_per_app,motivazione) values ('$idregole','".aggslashdb($tipotariffa)."','$lista_app')");
-echo mex("La regola di assegnazione",$pag)." 2 ".mex("è stata inserita",$pag).".<br>";
+else {
+esegui_query("insert into $tableregole (idregole,tariffa_per_app,motivazione) values ('$idregole','".aggslashdb($tipotariffa)."','$lista_app')");
+if ($num_apti > 1) esegui_query("update $tableregole set motivazione3 = '$v_apti$num_apti' where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
+} # fine else if ($regola_2b)
+echo "<br>".mex("La regola di assegnazione",$pag)." 2 ".mex("è stata inserita",$pag).".<br><br>";
 } # fine else if ($num_regole_esistente != 0)
 $aggiorna_ic_disp = 1;
 } # fine if ($inserire != "NO")
@@ -351,7 +389,7 @@ if ($tabelle_lock) unlock_tabelle($tabelle_lock);
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div>";
+<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>";
 
 if ($aggiorna_ic_disp or $aggiorna_ic_tar) {
 $lock = 1;
@@ -450,12 +488,26 @@ tab_app.style.visibility = 'hidden';
 tab_app.innerHTML = '';
 } // fine function nasc_app
 
+function aggiorna_vic_reg2 () {
+var sel_t2na = document.getElementById(\"t2na\");
+var num_sel = sel_t2na.selectedIndex;
+var num_app = sel_t2na.options[num_sel].value;
+var txt_vic = document.getElementById(\"vcn_r2\");
+if (num_app > 1) txt_vic.style.display = 'inline';
+else txt_vic.style.display = 'none';
+}
+
 function aggiorna_val_reg2 () {
 var sel_tar = document.getElementById(\"t2\");
 var num_sel = sel_tar.selectedIndex;
 var tariffa = sel_tar.options[num_sel].value;
 var txt_box = document.getElementById(\"v2\");
-if (tariffa == '') txt_box.disabled = true;
+var sel_t2na = document.getElementById(\"t2na\");
+var num_opt = sel_t2na.options.length;
+if (tariffa == '') {
+txt_box.disabled = true;
+sel_t2na.selectedIndex = 0;
+}
 else txt_box.disabled = false;
 txt_box.value = \"\";
 ";
@@ -464,10 +516,23 @@ $num_regole2 = numlin_query($regole2);
 for ($num1 = 0 ; $num1 < $num_regole2 ; $num1++) {
 $tariffa = risul_query($regole2,$num1,'tariffa_per_app');
 $lista_app = risul_query($regole2,$num1,'motivazione');
-echo "if (tariffa == \"$tariffa\") txt_box.value = \"$lista_app\";
+$num_apti = risul_query($regole2,$num1,'motivazione3');
+$v_apti = "true";
+if (substr($num_apti,0,1) == "v") $num_apti = substr($num_apti,1);
+elseif ($num_apti) $v_apti = "false";
+if (!$num_apti) $num_apti = 1;
+echo "if (tariffa == \"$tariffa\") {
+txt_box.value = \"$lista_app\";
+var n_a = '$num_apti';
+document.getElementById(\"v2na\").checked = $v_apti;
+}
+for (n1 = 0 ; n1 < num_opt ; n1++) {
+if (sel_t2na.options[n1].value == n_a) sel_t2na.selectedIndex = n1;
+}
 ";
 } # fine for $num1
 echo "
+aggiorna_vic_reg2();
 nasc_app ('')
 } // fine function aggiorna_val_reg2
 
@@ -635,7 +700,7 @@ $array_maxocc
 -->
 </script>
 
-<div style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)." <b>2</b>.</div><br>
+<div id=\"hreg2\" style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)." <b>2</b>.</div><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -654,7 +719,12 @@ echo "
 <option value=\"$tariffa\">$tariffa_vedi$nometariffa_vedi</option>";
 } # fine for $numtariffa
 echo "</select>
- ".mex("assegna automaticamente gli appartamenti",'unit.php')."
+ ".mex("assegna automaticamente",$pag)." <select name=\"num_apti\" id=\"t2na\" onchange=\"aggiorna_vic_reg2()\">";
+for ($num1 = 1 ; $num1 <= $num_appartamenti ; $num1++) {
+if ($num1 == 1) echo "<option value=\"1\" selected>".mex("un appartamento",'unit.php')."</option>";
+else echo "<option value=\"$num1\">$num1 ".mex("appartamenti",'unit.php')."</option>";
+} # fine for $num1
+echo "</select><span id=\"vcn_r2\"> (<label><input type=\"checkbox\" name=\"v_apti\" id=\"v2na\" value=\"v\" checked>".mex("vicini",'unit.php')."</label>)</span> ".mex("tra",$pag)."
  <input type=\"text\" id=\"v2\" name=\"lista_app\" size=\"15\" onclick=\"nasc_app('')\"><input class=\"dbutton\" id=\"mapp\" onclick=\"mos_app('')\" value=\"..\" type=\"button\">
  (".mex("lista di appartamenti separati da virgole",'unit.php').")
  ".mex("se non si inserisce nessun altro metodo di assegnazione",$pag).".<br>";
@@ -663,13 +733,26 @@ echo "<script type=\"text/javascript\">
 var txt_box = document.getElementById(\"v2\");
 txt_box.disabled = true;
 document.write('<div id=\"tab_app\" style=\"visibility: hidden;\"><\/div>');
+document.getElementById(\"vcn_r2\").style.display = 'none';
 -->
 </script>
 <div style=\"text-align: center;\">
 <button class=\"irul\" type=\"submit\"><div>".mex("Inserisci o modifica la regola",$pag)." 2</div></button>
-</div></div></form>
+</div></div></form>";
 
-<br><br>
+if ($tipotariffa_regola2 and preg_replace("/tariffa[0-9]+/","",$tipotariffa_regola2) == "") {
+echo "<script type=\"text/javascript\">
+<!--
+var sel_tr2 = document.getElementById(\"t2\");
+sel_tr2.value = '$tipotariffa_regola2';
+aggiorna_val_reg2();
+mos_app('');
+-->
+</script>
+";
+} # fine if ($tipotariffa_regola2)
+
+echo "<br><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div class=\"linhbox\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -733,8 +816,8 @@ $utente_t = risul_query($regole3,$num1,'iddatainizio');
 echo "if (tariffa == \"$tariffa\") ind_val = \"$utente_t\";
 ";
 } # fine for $num1
-echo "var num_opt = sel_ute.length;
-for (n1 = 1 ; n1 <= num_opt ; n1++) {
+echo "var num_opt = sel_ute.options.length;
+for (n1 = 0 ; n1 < num_opt ; n1++) {
 if (sel_ute.options[n1].value == ind_val) sel_ute.selectedIndex = n1;
 }
 }
