@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -217,7 +217,7 @@ $mostra_tabella_iniziale = "NO";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
+<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form>";
 unlock_tabelle($tabelle_lock);
 } # fine if ($continua == "NO")
@@ -240,7 +240,7 @@ esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersona
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('aggiunta_tronca_nomi_tab1','$nuovo_id','-2')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('linee_ripeti_date_tab_mesi','$nuovo_id','25')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('mostra_giorni_tab_mesi','$nuovo_id','NO')");
-esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('colori_tab_mesi','$nuovo_id','#70C6D4,#FFEA00,#FF9900,#FF3115')");
+esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('colori_tab_mesi','$nuovo_id','#70C6D4,#FFD800,#FF9900,#FF3115')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_linee_tab2_prenota','$nuovo_id','30')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza) values ('nomi_contratti','$nuovo_id','".aggslashdb($nomi_contr)."')");
 esegui_query("insert into $tablepersonalizza (idpersonalizza,idutente,valpersonalizza_num) values ('num_righe_tab_tutte_prenota','$nuovo_id','200')");
@@ -283,7 +283,7 @@ unset($linee);
 $num_lin = 0;
 for ($num1 = 0 ; $num1 < count($file_tema) ; $num1++) {
 if (substr($file_tema[$num1],0,2) == "?>") {
-$linee[$num_lin] = "\$tema[".$nuovo_id."] = \"sim\";
+$linee[$num_lin] = "\$tema[".$nuovo_id."] = \"blu\";
 ";
 $num_lin++;
 $linee[$num_lin] = $file_tema[$num1];
@@ -331,12 +331,12 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.ph
 ".mex("Ripeti la password",$pag).": <input type=\"password\" name=\"seconda_pass\" size=\"12\"><br><br>";
 echo "<input type=\"hidden\" name=\"tipo_pass$id\" value=\"$n_tipo_pass\">";
 if ($cambiato == "SI") echo "<hr style=\"width: 45%; margin-left: 0; text-align: left;\">";
-echo "<input class=\"sbutton\" type=\"submit\" name=\"cont\" value=\"".mex("Continua",$pag)."\">
+echo "<button class=\"cont\" type=\"submit\"><div>".mex("Continua",$pag)."</div></button>
 </div></form><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
+<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form>";
 } # fine if (!$continua)
 if ($continua == "SI") {
@@ -408,7 +408,7 @@ else { $checked = ""; $tag_b = ""; $slash_b = ""; }
 echo "<label><input type=\"checkbox\" name=\"gruppo$id_gruppo\" value=\"SI\"$checked> $tag_b".$nome_gruppo[$id_gruppo]."$slash_b</label><br>";
 } # fine for $num1
 echo "".mex("Nuovo gruppo",$pag)." <input type=\"text\" name=\"nuovo_gruppo\" size=\"12\"><br><br>
-<input class=\"sbutton\" type=\"submit\" name=\"cont\" value=\"".mex("Modifica",$pag)."\">
+<button class=\"edit\" type=\"submit\"><div>".mex("Modifica",$pag)."</div></button>
 </div></form><br><hr style=\"width: 45%; margin-left: 0; text-align: left;\"><br>";
 } # fine if (!$continua)
 if ($continua == "SI") {
@@ -460,7 +460,7 @@ if ($mostra_tabella_iniziale == "NO") {
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
+<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form>";
 } # fine if ($mostra_tabella_iniziale == "NO")
 } # fine if ($modifica_gruppi)
@@ -506,12 +506,12 @@ echo "".mex("Si è sicuri di voler <b style=\"font-weight: normal; color: red;\"
 <input type=\"hidden\" name=\"cancella\" value=\"SI\">
 <input type=\"hidden\" name=\"id_utente_canc\" value=\"$id_utente_canc\">
 <input type=\"hidden\" name=\"continua\" value=\"SI\">
-<input class=\"sbutton\" type=\"submit\" value=\"".mex("SI",$pag)."\">
+<button class=\"cusr\" type=\"submit\"><div>".mex("SI",$pag)."</div></button>
 </div></form></td><td>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"gestione_utenti.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input class=\"sbutton\" type=\"submit\" value=\"".mex("NO",$pag)."\">
+<button class=\"gobk\" type=\"submit\"><div>".mex("NO",$pag)."</div></button>
 </div></form></td></tr></table><br>";
 } # fine if ($continua != "SI")
 else {
@@ -624,6 +624,8 @@ $e_regole1_consentite = aggslashdb(risul_query($priv,$num1,'regole1_consentite')
 $e_tariffe_consentite = aggslashdb(risul_query($priv,$num1,'tariffe_consentite'));
 $e_costi_agg_consentiti = aggslashdb(risul_query($priv,$num1,'costi_agg_consentiti'));
 $e_contratti_consentiti = aggslashdb(risul_query($priv,$num1,'contratti_consentiti'));
+$e_casse_consentite = aggslashdb(risul_query($priv,$num1,'casse_consentite'));
+$e_cassa_pagamenti = aggslashdb(risul_query($priv,$num1,'cassa_pagamenti'));
 $e_priv_ins_prenota = aggslashdb(risul_query($priv,$num1,'priv_ins_prenota'));
 $e_priv_mod_prenota = aggslashdb(risul_query($priv,$num1,'priv_mod_prenota'));
 $e_priv_mod_pers = aggslashdb(risul_query($priv,$num1,'priv_mod_pers'));
@@ -635,8 +637,8 @@ $e_priv_ins_tariffe = aggslashdb(risul_query($priv,$num1,'priv_ins_tariffe'));
 $e_priv_ins_regole = aggslashdb(risul_query($priv,$num1,'priv_ins_regole'));
 $e_priv_messaggi = aggslashdb(risul_query($priv,$num1,'priv_messaggi'));
 $e_priv_inventario = aggslashdb(risul_query($priv,$num1,'priv_inventario'));
-esegui_query("insert into $tableprivilegi (idutente,anno,regole1_consentite,tariffe_consentite,costi_agg_consentiti,contratti_consentiti,priv_ins_prenota,priv_mod_prenota,priv_mod_pers,priv_ins_clienti,prefisso_clienti,priv_ins_costi,priv_vedi_tab,priv_ins_tariffe,priv_ins_regole,priv_messaggi,priv_inventario)
- values ('$id_utente_importa','$e_anno','$e_regole1_consentite','$e_tariffe_consentite','$e_costi_agg_consentiti','$e_contratti_consentiti','$e_priv_ins_prenota','$e_priv_mod_prenota','$e_priv_mod_pers','$e_priv_ins_clienti','$e_prefisso_clienti','$e_priv_ins_costi','$e_priv_vedi_tab','$e_priv_ins_tariffe','$e_priv_ins_regole','$e_priv_messaggi','$e_priv_inventario')");
+esegui_query("insert into $tableprivilegi (idutente,anno,regole1_consentite,tariffe_consentite,costi_agg_consentiti,contratti_consentiti,casse_consentite,cassa_pagamenti,priv_ins_prenota,priv_mod_prenota,priv_mod_pers,priv_ins_clienti,prefisso_clienti,priv_ins_costi,priv_vedi_tab,priv_ins_tariffe,priv_ins_regole,priv_messaggi,priv_inventario)
+ values ('$id_utente_importa','$e_anno','$e_regole1_consentite','$e_tariffe_consentite','$e_costi_agg_consentiti','$e_contratti_consentiti','$e_casse_consentite','$e_cassa_pagamenti','$e_priv_ins_prenota','$e_priv_mod_prenota','$e_priv_mod_pers','$e_priv_ins_clienti','$e_prefisso_clienti','$e_priv_ins_costi','$e_priv_vedi_tab','$e_priv_ins_tariffe','$e_priv_ins_regole','$e_priv_messaggi','$e_priv_inventario')");
 if ($e_anno != 1) {
 $tipo_periodi_cambia = esegui_query("select * from $tableanni where idanni = '$e_anno'");
 $tipo_periodi_cambia = risul_query($tipo_periodi_cambia,0,'tipo_periodi');
