@@ -114,6 +114,7 @@ $files_sorgente = array(
 'img/croom.png',
 'img/crule.png',
 'img/ctaxes.png',
+'img/cuser.png',
 'img/dir1_des.png',
 'img/dir1_sin.png',
 'img/dir2_des.png',
@@ -226,13 +227,13 @@ $files_sorgente = array(
 'img/website_mini.png',
 'img/website.png',
 'img/websites.png',
+'img/xavail.png',
 'img/xclient.png',
 'img/xdocument.png',
 'img/xextracost.png',
 'img/xinventory.png',
 'img/xprices.png',
 'img/xuser.png',
-
 'includes/',
 'includes/costanti.php',
 'includes/dati_form_prenotazione.php',
