@@ -53,8 +53,13 @@ $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',2.14);
-define('C_PHPR_VERSIONE_TXT',"2.1.4");
+define('C_PHPR_VERSIONE_NUM',2.20);
+define('C_PHPR_VERSIONE_TXT',"2.2.0");
+
+if (!function_exists('utf8_encode')) {
+function utf8_encode ($testo) { return ($testo); }
+function utf8_decode ($testo) { return ($testo); }
+} # fine if (!function_exists('utf8_encode'))
 
 # Se non si specifica nessun anno uso l'attuale
 $anno_corrente = date("Y",(time() + (C_DIFF_ORE * 3600)));
@@ -885,12 +890,15 @@ $last_dates_menu = $file;
 
 
 
-function allunga_tempo_limite ($n_lim="") {
+function allunga_tempo_limite ($n_lim="",$agg_lim="") {
 
 if (function_exists('set_time_limit')) {
 if (!strcmp($n_lim,"")) $n_lim = 420;
 $lim_att = 30;
-if (function_exists('ini_get')) $lim_att = ini_get('max_execution_time');
+if (function_exists('ini_get')) {
+$lim_att = ini_get('max_execution_time');
+if (strcmp($agg_lim,"")) $n_lim = $lim_att + $agg_lim;
+} # fine if (function_exists('ini_get'))
 if ($lim_att < $n_lim) set_time_limit($n_lim);
 } # fine if (function_exists('set_time_limit')
 
