@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2013 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -31,6 +31,7 @@ $lingua_mex_orig = $lingua_mex;
 include_once("./includes/funzioni_menu.php");
 include(C_DATI_PATH."/lingua.php");
 $lingua_mex = $lingua[1];
+if (function_exists('ini_set')) @ini_set('opcache.enable',0);
 
 $tableanni = $PHPR_TAB_PRE."anni";
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
@@ -116,7 +117,7 @@ crea_indice($tablerclientiprenota,"idprenota",$PHPR_TAB_PRE."iidprclientiprenota
 
 # Creo la tabella per le regole di assegnazione
 $tableregole = $PHPR_TAB_PRE."regole".$anno;
-$col_tableregole = "idregole integer, app_agenzia varchar(100), tariffa_chiusa text, tariffa_per_app text, tariffa_per_utente text, tariffa_per_persone text, tariffa_commissioni integer, iddatainizio integer, iddatafine integer, motivazione text, motivazione2 text";
+$col_tableregole = "idregole integer, app_agenzia varchar(100), tariffa_chiusa text, tariffa_per_app text, tariffa_per_utente text, tariffa_per_persone text, tariffa_commissioni integer, iddatainizio integer, iddatafine integer, motivazione text, motivazione2 text, motivazione3 text";
 esegui_query("create table $tableregole ($col_tableregole)");
 $col_tableregole = estrai_col_tabella($col_tableregole);
 
@@ -478,6 +479,7 @@ $tariffa_commissioni = risul_query($regole_prec,$num1,'tariffa_commissioni');
 $iddatainizio = risul_query($regole_prec,$num1,'iddatainizio');
 $motivazione = risul_query($regole_prec,$num1,'motivazione');
 $motivazione2 = risul_query($regole_prec,$num1,'motivazione2');
+$motivazione3 = risul_query($regole_prec,$num1,'motivazione3');
 if ($iddatainizio < $id_data_ini_periodi_prec) { $iddatainizio = $id_data_ini_periodi_prec; }
 $iddatainizio = $iddatainizio - $id_data_ini_periodi_prec + 1;
 $iddatafine = risul_query($regole_prec,$num1,'iddatafine');
@@ -490,6 +492,7 @@ else esegui_query("insert into $tableregole (idregole,app_agenzia,iddatainizio,i
 } # fine else $tariffa_commissioni)
 if (strcmp($motivazione,"")) esegui_query("update $tableregole set motivazione = '".aggslashdb($motivazione)."' where idregole = '$idregole' ");
 if (strcmp($motivazione2,"")) esegui_query("update $tableregole set motivazione2 = '".aggslashdb($motivazione2)."' where idregole = '$idregole' ");
+if (strcmp($motivazione3,"")) esegui_query("update $tableregole set motivazione3 = '".aggslashdb($motivazione3)."' where idregole = '$idregole' ");
 } # fine for $num1
 
 $soldi_importati = esegui_query("select * from $tablesoldi_prec where data_inserimento >= '$data_inizio_periodi' and  saldo_prenota is not NULL order by idsoldi");
