@@ -97,6 +97,7 @@ return $dati_tariffe;
 
 
 
+# Vecchia funzione (rimuoverla quando non è più usata da nessuna parte), da ripiazzare con dati_regole2
 function trova_app_regola2 ($tipotariffa,&$regole2,&$num_regole2,&$app_regola2_predef,&$id_periodo_corrente,$idinizioperiodo,$idfineperiodo,$tipo_periodi,$anno,$tableregole) {
 
 $app_regola2_predef = "";
@@ -135,6 +136,58 @@ return $lista_app;
 
 
 
+# Nuova funzione alternativa a trova_app_regola2
+function dati_regole2 (&$dati_r2,&$app_regola2_predef,$tipotariffa,$idinizioperiodo,$idfineperiodo,&$id_periodo_corrente,$tipo_periodi,$anno,$tableregole) {
+
+if (!is_array($dati_r2)) {
+$regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''");
+$dati_r2['num'] = numlin_query($regole2);
+
+for ($num1 = 0 ; $num1 < $dati_r2['num'] ; $num1++) {
+$tariffa_r2 = risul_query($regole2,$num1,'tariffa_per_app');
+$dati_r2[$tariffa_r2] = risul_query($regole2,$num1,'motivazione');
+$dati_r2['l2'][$tariffa_r2] = risul_query($regole2,$num1,'motivazione2');
+if (strcmp($dati_r2['l2'][$tariffa_r2],"")) {
+$dati_r2['dini'][$tariffa_r2] = risul_query($regole2,$num1,'iddatainizio');
+if (!$dati_r2['dini'][$tariffa_r2]) $dati_r2['dfine'][$tariffa_r2] = risul_query($regole2,$num1,'iddatafine');
+} # fine if (strcmp($dati_r2['l2'][$tariffa_r2],""))
+$napp = risul_query($regole2,$num1,'motivazione3');
+if ($napp) {
+if (substr($napp,0,1) == "v") {
+$napp = substr($napp,1);
+$dati_r2['napp']['v'][$tariffa_r2] = 1;
+} # fine if (substr($napp,0,1) == "v")
+$dati_r2['napp'][$tariffa_r2] = $napp;
+} # fine if ($napp)
+} # fine for $num1
+} # fine if (!is_array($dati_r2))
+
+$app_regola2_predef = "";
+if ($tipotariffa) {
+$lista_app = $dati_r2[$tipotariffa];
+if (strcmp($dati_r2['l2'][$tipotariffa],"")) {
+if (!$id_periodo_corrente) $id_periodo_corrente = calcola_id_periodo_corrente($anno);
+$ngiorni_reg2b = $dati_r2['dini'][$tipotariffa];
+if ($ngiorni_reg2b) $diff_giorni = $idinizioperiodo - $id_periodo_corrente + 1;
+else {
+$ngiorni_reg2b = $dati_r2['dfine'][$tipotariffa];
+$diff_giorni = $idfineperiodo - $id_periodo_corrente + 1;
+} # fine else if ($ngiorni_reg2b)
+if ($tipo_periodi == "s") $diff_giorni = $diff_giorni * 7;
+if ($diff_giorni < $ngiorni_reg2b) {
+$app_regola2_predef = $dati_r2[$tipotariffa];
+$lista_app = $dati_r2['l2'][$tipotariffa];
+} # fine if ($diff_giorni < $ngiorni_reg2b)
+} # fine if (strcmp($dati_r2['l2'][$tipotariffa],""))
+
+return $lista_app;
+} # fine if ($tipotariffa)
+
+} # fine function dati_regole2
+
+
+
+
 function calcola_commissioni ($dati_tariffe,$tipotariffa,$iddataini,$iddatafine,$tariffesettimanali,$sconto,$prezzo_costi_tot) {
 
 $commissioni = (double) 0;
