@@ -294,6 +294,16 @@ case "Spostamento orizzontale della posizione":	$messaggio = "Horizontal offset
 case "aggiunto al commento":  			$messaggio = "added to comment"; break;
 case "aggiunto al campo":  			$messaggio = "added to field"; break;
 case "del cliente":  				$messaggio = "in client data"; break;
+case "URL file css":  				$messaggio = "URL of css file"; break;
+case "ci sono tariffe senza regola di assegnazione n. 2":	$messaggio = "there are rates without assignment rule n. 2"; break;
+case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
+case "Partita iva":  				$messaggio = "VAT number"; break;
+case "mai":  					$messaggio = "never"; break;
+case "se possibile":  				$messaggio = "when possible"; break;
+case "sempre":  				$messaggio = "always"; break;
+case "chiedere":  				$messaggio = "ask"; break;
+case "posizioni vicine":  			$messaggio = "nearby positions"; break;
+case "con posizioni vicine":  			$messaggio = "with nearby positions"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -424,6 +434,7 @@ case "var_chiedi_numero_appartamenti_per_tipologia":	$messaggio = "var_ask_numbe
 case "var_massimo_numero_appartamenti_per_tipologia":	$messaggio = "var_maximum_number_apartments_for_type"; break;
 case "var_aggiungi_altre_tipologie":  		$messaggio = "var_add_other_types"; break;
 case "var_massimo_numero_altre_tipologie":  	$messaggio = "var_maximum_number_other_types"; break;
+case "var_cerca_appartamenti_vicini":  		$messaggio = "var_search_nearby_apartments"; break;
 case "var_fr_Numero_di":  			$messaggio = "var_phr_Number_of"; break;
 case "var_fr_Il_numero_di":  			$messaggio = "var_phr_The_number_of"; break;
 case "var_fr_richiesto_e_sbagliato":  		$messaggio = "var_phr_inserted_is_wrong"; break;
@@ -491,6 +502,8 @@ case "var_chiedi_telefono":  			$messaggio = "var_ask_telephone"; break;
 case "var_chiedi_telefono2":  			$messaggio = "var_ask_telephone2"; break;
 case "var_chiedi_telefono3":  			$messaggio = "var_ask_telephone3"; break;
 case "var_chiedi_fax":  			$messaggio = "var_ask_fax"; break;
+case "var_chiedi_codfiscale":  			$messaggio = "var_ask_fiscalcode"; break;
+case "var_chiedi_partitaiva":  			$messaggio = "var_ask_vatnumber"; break;
 case "var_chiedi_commento":  			$messaggio = "var_ask_comment"; break;
 case "var_chiedi_oracheckin":  			$messaggio = "var_ask_checkintime"; break;
 case "var_chiedi_metodopagamento":  		$messaggio = "var_ask_paymentmethod"; break;
@@ -515,6 +528,8 @@ case "var_fr_Telefono":  			$messaggio = "var_phr_Telephone"; break;
 case "var_fr_Secondo_telefono":  		$messaggio = "var_phr_Second_telephone"; break;
 case "var_fr_Terzo_telefono":  			$messaggio = "var_phr_Third_telephone"; break;
 case "var_fr_Fax":  				$messaggio = "var_phr_Fax"; break;
+case "var_fr_Codice_fiscale":  			$messaggio = "var_phr_Fiscal_code"; break;
+case "var_fr_Partita_iva":  			$messaggio = "var_phr_VAT_number"; break;
 case "var_fr_Orario_stimato_di_arrivo":  	$messaggio = "var_phr_Estimated_arrival_time"; break;
 case "var_fr_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phr_Deposit_payment_method"; break;
 case "var_fre_Cognome":  			$messaggio = "var_phre_Surname"; break;
@@ -531,6 +546,8 @@ case "var_fre_Telefono":  			$messaggio = "var_phre_Telephone"; break;
 case "var_fre_Secondo_telefono":  		$messaggio = "var_phre_Second_telephone"; break;
 case "var_fre_Terzo_telefono":  		$messaggio = "var_phre_Third_telephone"; break;
 case "var_fre_Fax":  				$messaggio = "var_phre_Fax"; break;
+case "var_fre_Codice_fiscale":  		$messaggio = "var_phre_Fiscal_code"; break;
+case "var_fre_Partita_iva":  			$messaggio = "var_phre_VAT_number"; break;
 case "var_fre_Orario_stimato_di_arrivo":  	$messaggio = "var_phre_Estimated_arrival_time"; break;
 case "var_fre_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phre_Deposit_payment_method"; break;
 case "var_fr_campi_necessari":  		$messaggio = "var_phr_required_fields"; break;
@@ -552,6 +569,8 @@ case "var_fr_Data_di_partenza":  		$messaggio = "var_phr_Departure_date"; break;
 case "var_fr_Tipologia":  			$messaggio = "var_phr_Type"; break;
 case "var_fr_Accetto":  			$messaggio = "var_phr_I_accept"; break;
 case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_phr_The_requested_type_is_closed_in_this_period"; break;
+case "var_fr_posizioni_vicine":  		$messaggio = "var_phr_nearby_positions"; break;
+case "var_fr_con_posizioni_vicine":  		$messaggio = "var_phr_with_nearby_positions"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
 
