@@ -33,6 +33,9 @@ case "Non si è potuto stabilire la connessione":	$messaggio = "It was not possi
 case "Non ho i permassi di scrittura sulla cartella dati":	$messaggio = "I don't have write premissions on dati folder"; break;
 case "Prova a mantenere i dati degli anni non presenti nell'installazione remota":	$messaggio = "Try to retain data of years not present in remote installation"; break;
 case "nella pagina delle interconnessioni":  	$messaggio = "in interconnections page"; break;
+case "Modifica la regola di assegnazione":  	$messaggio = "Modify the assignment rule"; break;
+case "La prenotazione cancellata non era presente nel database":	$messaggio = "The deleted reservation was not present in the database"; break;
+case "gruppo":  				$messaggio = "group"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
