@@ -31,14 +31,14 @@ case "Non è stato possibile creare il nuovo database, controllare i dati per la
 case "Non ho i permessi di scrittura sulla cartella dati":	$messaggio = "No tengo los permisos de escritura sobre el directorio dati"; break;
 case "La versione attuale di hoteldruid e quella del file non coincidono":	$messaggio = "La versión actual de hoteldruid y la del archivo no coinciden"; break;
 case "Non ho potuto leggere il file":  		$messaggio = "No he podido leer el archivo"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Sistema di backup per HotelDruid":  	$messaggio = "Sistema de backup para HotelDruid"; break;
-case "Crea il file di backup":  		$messaggio = "Crea el archivo de backup"; break;
-case "Crea un nuovo file di backup":  		$messaggio = "Crea un nuevo archivo de backup"; break;
+case "Crea il file di backup":  		$messaggio = "Crear el archivo de backup"; break;
+case "Crea un nuovo file di backup":  		$messaggio = "Crear un nuevo archivo de backup"; break;
 case "sovrascrivendo l'attuale":  		$messaggio = "escibiendolo encima del actual"; break;
-case "Guarda il file":				$messaggio = "Mira el archivo"; break;
+case "Guarda il file":				$messaggio = "Mirar el archivo"; break;
 case "per salvarlo (eventualmente usa il bottone indietro del browser per tornare qui)":	$messaggio = "para guardarlo (eventualmente utilizar el botón atrás del navegador para volver aquí)"; break;
-case "Cancella":  				$messaggio = "Borra"; break;
+case "Cancella":  				$messaggio = "Borrar"; break;
 case " l'attuale file di backup":  		$messaggio = " el actual archivo de backup"; break;
 case "Ripristina i dati dal file":  		$messaggio = "Restaurar los datos desde el archivo"; break;
 case " (i dati attuali verranno cancellati), utilizzando per la connessione al database:":	$messaggio = " (los datos actuales serán borrados), utilizando para la creación de la base de datos:"; break;
@@ -46,7 +46,7 @@ case "i dati dell'attuale connessione":  	$messaggio = "los datos de la conexió
 case "nuovi dati":  				$messaggio = "nuevos datos"; break;
 case "Ho fatto l'upload del file":		$messaggio = "He hecho el upload del archivo"; break;
 case "Non ho potuto fare l'upload del file":	$messaggio = "No ha sido posible hacer el upload del archivo"; break;
-case "Fai l'upload":  				$messaggio = "Haz el upload"; break;
+case "Fai l'upload":  				$messaggio = "Hacer el upload"; break;
 case " del file di backup":  			$messaggio = " del archivo de backup"; break;
 case " di un nuovo file di backup":  		$messaggio = " de un nuevo archivo de backup"; break;
 case "Prefisso nel nome delle tabelle":		$messaggio = "Prefijo en el nombre de las tablas"; break;
@@ -56,8 +56,8 @@ case "Il contenuto del file inviato non è corretto":	$messaggio = "El contenido
 case "Il formato del file è errato":  		$messaggio = "El formato del archivo no es correcto"; break;
 case "Compresso":  				$messaggio = "Comprimido"; break;
 case "Backup dei documenti":  			$messaggio = "Backup de los documentos"; break;
-case "Crea il file di backup dei documenti":  	$messaggio = "Crea el archivo de backup de los documentos"; break;
-case "Crea un nuovo file di backup dei documenti":	$messaggio = "Crea un nuevo archivo de backup de los documentos"; break;
+case "Crea il file di backup dei documenti":  	$messaggio = "Crear el archivo de backup de los documentos"; break;
+case "Crea un nuovo file di backup dei documenti":	$messaggio = "Crear un nuevo archivo de backup de los documentos"; break;
 case " del file di backup dei documenti":	$messaggio = " del archivo de backup de los documentos"; break;
 case " di un nuovo file di backup dei documenti":	$messaggio = " de un nuevo archivo de backup de los documentos"; break;
 case " l'attuale file di backup dei documenti":	$messaggio = " el actual archivo de backup de los documentos"; break;
