@@ -6,8 +6,8 @@ switch ($messaggio) {
 # translate YES and NO in upper case
 case "SI":  					$messaggio = "SI"; break;
 case "NO":  					$messaggio = "NO"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
-case "Crea pagine per il sito web":  		$messaggio = "Crea páginas para el sitio web"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
+case "Crea pagine per il sito web":  		$messaggio = "Crear páginas para el sitio web"; break;
 case "Dati comuni":  				$messaggio = "Datos comunes"; break;
 case "Utilizza i dati attuali per la connessione al database":	$messaggio = "Utiliza los datos actuales para conectar a la base de datos"; break;
 case "Utilizza altri dati per la connessione al database":	$messaggio = "Utiliza otros datos para conectar a la base de datos"; break;
@@ -72,8 +72,8 @@ case "Tag html di apertura per la formattazione delle font":	$messaggio = "Eleme
 case "Tag html di chiusura per la formattazione delle font":	$messaggio = "Elemento html de cierre para dar formato a las letras"; break;
 case "Tag html di apertura per la formattazione delle font rosse":	$messaggio = "Elemento html de apertura para dar formato a las letras rojas"; break;
 case "Tag html di chiusura per la formattazione delle font rosse":	$messaggio = "Elemento html de cierre para dar formato a las letras rojas"; break;
-case "Crea la pagina per la disponibilità":  	$messaggio = "Crea la página para la disponibilidad"; break;
-case "Controlla la disponibilità":  		$messaggio = "Controla la disponibilidad"; break;
+case "Crea la pagina per la disponibilità":  	$messaggio = "Crear la página para la disponibilidad"; break;
+case "Controlla la disponibilità":  		$messaggio = "Controlar la disponibilidad"; break;
 case "dal":  					$messaggio = "desde"; break;
 case "al":  					$messaggio = "hasta"; break;
 case "per la tipologia":  			$messaggio = "para la tipología"; break;
@@ -294,6 +294,16 @@ case "Spostamento orizzontale della posizione":	$messaggio = "Desplazamiento hor
 case "aggiunto al commento":  			$messaggio = "añadido al comentario"; break;
 case "aggiunto al campo":  			$messaggio = "añadido al campo"; break;
 case "del cliente":  				$messaggio = "del cliente"; break;
+case "URL file css":  				$messaggio = "URL del archivo css"; break;
+case "ci sono tariffe senza regola di assegnazione n. 2":	$messaggio = "hay tarifas sin regla de asignación n. 2"; break;
+case "Codice fiscale":  			$messaggio = "N. Identificación Fiscal"; break;
+case "Partita iva":  				$messaggio = "Cert. Identificación Fiscal"; break;
+case "mai":  					$messaggio = "nunca"; break;
+case "se possibile":  				$messaggio = "si es posible"; break;
+case "sempre":  				$messaggio = "siempre"; break;
+case "chiedere":  				$messaggio = "preguntar"; break;
+case "posizioni vicine":  			$messaggio = "posiciones_cercanas"; break;
+case "con posizioni vicine":  			$messaggio = "con posiciones cercanas"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
@@ -424,6 +434,7 @@ case "var_chiedi_numero_appartamenti_per_tipologia":	$messaggio = "var_pide_nume
 case "var_massimo_numero_appartamenti_per_tipologia":	$messaggio = "var_maximo_numero_apartamentos_por_tipologia"; break;
 case "var_aggiungi_altre_tipologie":  		$messaggio = "var_agnade_otras_tipologias"; break;
 case "var_massimo_numero_altre_tipologie":  	$messaggio = "var_maximo_numero_otras_tipologias"; break;
+case "var_cerca_appartamenti_vicini":  		$messaggio = "var_busca_apartamentos_cercanos"; break;
 case "var_fr_Numero_di":  			$messaggio = "var_fr_Numero_de"; break;
 case "var_fr_Il_numero_di":  			$messaggio = "var_fr_El_numero_de"; break;
 case "var_fr_richiesto_e_sbagliato":  		$messaggio = "var_fr_pedido_esta_equivocado"; break;
@@ -491,6 +502,8 @@ case "var_chiedi_telefono":  			$messaggio = "var_pedir_telefono"; break;
 case "var_chiedi_telefono2":  			$messaggio = "var_pedir_telefono2"; break;
 case "var_chiedi_telefono3":  			$messaggio = "var_pedir_telefono3"; break;
 case "var_chiedi_fax":  			$messaggio = "var_pedir_fax"; break;
+case "var_chiedi_codfiscale":  			$messaggio = "var_pedir_numidfiscal"; break;
+case "var_chiedi_partitaiva":  			$messaggio = "var_pedir_certidfiscal"; break;
 case "var_chiedi_commento":  			$messaggio = "var_pedir_comentario"; break;
 case "var_chiedi_oracheckin":  			$messaggio = "var_pedir_horaentrada"; break;
 case "var_chiedi_metodopagamento":  		$messaggio = "var_pedir_metodopago"; break;
@@ -515,6 +528,8 @@ case "var_fr_Telefono":  			$messaggio = "var_fr_Telefono"; break;
 case "var_fr_Secondo_telefono":  		$messaggio = "var_fr_Segundo_telefono"; break;
 case "var_fr_Terzo_telefono":  			$messaggio = "var_fr_Tercer_telefono"; break;
 case "var_fr_Fax":  				$messaggio = "var_fr_Fax"; break;
+case "var_fr_Codice_fiscale":  			$messaggio = "var_fr_N_identificacion_fiscal"; break;
+case "var_fr_Partita_iva":  			$messaggio = "var_fr_Cert_identificacion_fiscal"; break;
 case "var_fr_Orario_stimato_di_arrivo":  	$messaggio = "var_fr_Horario_estimativo_de_llegada"; break;
 case "var_fr_Metodo_di_pagamento_della_caparra":	$messaggio = "var_fr_Metodo_de_pago_de_la_fianza"; break;
 case "var_fre_Cognome":  			$messaggio = "var_fre_Apellido"; break;
@@ -531,6 +546,8 @@ case "var_fre_Telefono":  			$messaggio = "var_fre_Telefono"; break;
 case "var_fre_Secondo_telefono":  		$messaggio = "var_fre_Segundo_telefono"; break;
 case "var_fre_Terzo_telefono":  		$messaggio = "var_fre_Tercer_telefono"; break;
 case "var_fre_Fax":  				$messaggio = "var_fre_Fax"; break;
+case "var_fre_Codice_fiscale":  		$messaggio = "var_fre_N_identificacion_fiscal"; break;
+case "var_fre_Partita_iva":  			$messaggio = "var_fre_Cert_identificacion_fiscal"; break;
 case "var_fre_Orario_stimato_di_arrivo":  	$messaggio = "var_fre_Horario_estimativo_de_llegada"; break;
 case "var_fre_Metodo_di_pagamento_della_caparra":	$messaggio = "var_fre_Metodo_de_pago_de_la_fianza"; break;
 case "var_fr_campi_necessari":  		$messaggio = "var_fr_campos_necesarios"; break;
@@ -552,6 +569,8 @@ case "var_fr_Data_di_partenza":  		$messaggio = "var_fr_Fecha_de_salida"; break;
 case "var_fr_Tipologia":  			$messaggio = "var_fr_Tipologia"; break;
 case "var_fr_Accetto":  			$messaggio = "var_fr_Acepto"; break;
 case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_fr_La_tipologia_pedida_esta_cerrada_en_este_periodo"; break;
+case "var_fr_posizioni_vicine":  		$messaggio = "var_fr_posiciones_cercanas"; break;
+case "var_fr_con_posizioni_vicine":  		$messaggio = "var_fr_con_posiciones_cercanas"; break;
 case "var_":  		$messaggio = "var_"; break;
 case "var_":  		$messaggio = "var_"; break;
 
