@@ -50,6 +50,9 @@ case "configura e personalizza":		$messaggio = "configurar y personalizar"; brea
 case "per cambiare il nome della valuta, abilitare la registrazione delle entrate, inserire i metodi di pagamento, ed impostare molte altre opzioni":	$messaggio = "para cambiar el nombre de la divisa, habilitar el registro de entradas, insertar los métodos de pago, y configurar muchas otras opciones"; break;
 case "Inserisci il numero di tariffe, un nome per ciascuna di esse ed i prezzi corrispondenti dalla":	$messaggio = "Insertar el número de tarifas, un nombre para cada una de ellas y los precios correspondientes desde la"; break;
 case "questo programma":			$messaggio = "este programa"; break;
+case "Nome delle unità singole da gestire":	$messaggio = "Nombre de las unidades individuales a gestionar"; break;
+case "Numero di unità singole da gestire":	$messaggio = "Número de las unidades individuales a gestionar"; break;
+case "non incluse nelle unità normali":		$messaggio = "no incluídas en las unidades normales"; break;
 case "":			$messaggio = ""; break;
 case "":			$messaggio = ""; break;
 
