@@ -29,13 +29,13 @@ case "considera il costo settimanale come letto(i) aggiuntivo(i)":	$messaggio =
 case "considera il costo giornaliero come letto(i) aggiuntivo(i)":	$messaggio = "considera el coste diario como cama(s) extra(s)"; break;
 case "della tariffa arrotondato a":  		$messaggio = "de la tarifa redondeado a"; break;
 case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "considera el coste percentual como cama(s) extra(s)"; break;
-case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Sigue insertando el nuevo coste añadido"; break;
+case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Seguir insertando el nuevo coste añadido"; break;
 case "Caparra":  				$messaggio = "Fianza"; break;
 case "La caparra normale per la":  		$messaggio = "La fianza normal para la"; break;
 case "arrotondata a":  				$messaggio = "redondeada a"; break;
 case "Inserisci o modifica la caparra":  	$messaggio = "Insertar o modificar la fianza"; break;
 case "Vedi i prezzi già inseriti":  		$messaggio = "Mirar los precios ya insertados"; break;
-case "Torna al menù principale":  		$messaggio = "Vuelve al menú principal"; break;
+case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
 case "Si deve inserire la percentuale":  	$messaggio = "Hay que insertar la percentual"; break;
 case "La caparra è stata modificata":  		$messaggio = "La fianza ha sido modificada"; break;
 case "Si deve specificare quando applicare il costo di fine locazione":	$messaggio = "Hay que espicificar cuando aplicar el coste síngulo"; break;
@@ -99,7 +99,7 @@ case "assegnato automaticamente con tariffe":  	$messaggio = "asignado automatic
 case "nessuna":  				$messaggio = "ninguna"; break;
 case "scegliere":  				$messaggio = "escoger"; break;
 case "mostrare nella pagina di inserzione prenotazioni":	$messaggio = "enseñar en la página de inserción de reservas"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":	$messaggio = "Escoge las tarifas con las que será aplicado automaticamente el coste <b>síngulo</b>"; break;
 case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Escoge las tarifas con las que será aplicado automaticamente el coste <b>semanal</b>"; break;
 case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "Escoge las tarifas con las que será aplicado automaticamente el coste <b>diario</b>"; break;
