@@ -2,18 +2,18 @@
 
 switch ($messaggio) {
 
-case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Inserta las reglas de asignación para las reservas del año"; break;
+case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":	$messaggio = "Insertar las reglas de asignación para las reservas del año"; break;
 case "Regola di assegnazione":  		$messaggio = "Regla de asignación"; break;
 case "nel periodo dal":  			$messaggio = "en el período desde"; break;
 case "al":  					$messaggio = "hasta"; break;
 case "motivazione":  				$messaggio = "motivación"; break;
-case "Inserisci la regola":  			$messaggio = "Inserta la regla"; break;
-case "Inserisci o modifica la regola":  	$messaggio = "Inserta o modifica la regla"; break;
+case "Inserisci la regola":  			$messaggio = "Insertar la regla"; break;
+case "Inserisci o modifica la regola":  	$messaggio = "Insertar o modificar la regla"; break;
 case "Cancella tutte le regole di questo tipo":	$messaggio = "Borra todas las reglas de este tipo"; break;
 case "Quando si sceglie la tariffa":  		$messaggio = "Cuando se escoge la tarifa"; break;
 case "se non si inserisce nessun altro metodo di assegnazione":	$messaggio = "si no se inserta ningún otro método de asignación"; break;
-case "Vedi le regole già inserite":  		$messaggio = "Mira las reglas ya insertadas"; break;
-case "Torna al menù principale":  		$messaggio = "Vuelve al menú principal"; break;
+case "Vedi le regole già inserite":  		$messaggio = "Mirar las reglas ya insertadas"; break;
+case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
 case "Non sono stati inseriti tutti i dati necessari":	$messaggio = "No han sido insertados todos los datos necesarios"; break;
 case "Le date sono sbagliate":  		$messaggio = "Las fechas están equivocadas"; break;
 case "opzionale":  				$messaggio = "opcionál"; break;
@@ -26,7 +26,7 @@ case " non esiste":  				$messaggio = " no existe"; break;
 case "La regola di assegnazione":		$messaggio = "La regla de asignación"; break;
 case "è stata inserita":			$messaggio = "ha sido insertada"; break;
 case "è stata modificata":			$messaggio = "ha sido modificada"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Motivazione non valida":  		$messaggio = "Motivación no válida"; break;
 case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":	$messaggio = "La tarifa escogida ya tiene un usuario asociado, borra la regla antes de insertar una nueva"; break;
 case "Quando l'utente amministratore":  	$messaggio = "Cuando el usuario administrador"; break;
@@ -35,7 +35,7 @@ case "fai risultare come se l'utente":  	$messaggio = "haz resultar como si el u
 case "avesse inserito la prenotazione e l'eventuale cliente":	$messaggio = "hubiese insertado la reserva y el eventual cliente"; break;
 case "Si deve inserire l'utente da associare":	$messaggio = "Hay que insertar el usuario a asociar"; break;
 case "L'utente ":  				$messaggio = "El usuario "; break;
-case "assegna automaticamente come numero di persone":	$messaggio = "asigna automaticamente como número de personas"; break;
+case "assegna automaticamente come numero di persone":	$messaggio = "asignar automaticamente como número de personas"; break;
 case "se non si inserisce nessun altro numero":	$messaggio = "si no se inserta ningún otro número"; break;
 case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":	$messaggio = "La tarifa escogida ya tiene número de personas asociado, borra la regla antes de insertar una nueva"; break;
 case "Si deve inserire il numero di persone da associare":	$messaggio = "Hay que insertar el número de personas a asociar"; break;
@@ -53,6 +53,9 @@ case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "El
 case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">No ha sido posible</span> liberar de reservas el período cerrado"; break;
 case "per le tariffe":  			$messaggio = "para las tarifas"; break;
 case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "Existe ya una regla de este tipo en el período seleccionado"; break;
+case "assegna automaticamente":  		$messaggio = "asignar automaticamente"; break;
+case "tra":  					$messaggio = "entre"; break;
+case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "a asignar demasiado alto, supera el número presente en la lista"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
