@@ -11,10 +11,10 @@ case "password conservata criptata con md5":  	$messaggio = "contraseña guardad
 case "password conservata criptata con mcrypt":	$messaggio = "contraseña guardada encriptada con mcrypt"; break;
 case "password conservata criptata con mhash":	$messaggio = "contraseña guardada encriptada con mhash"; break;
 case "disabilitato":  				$messaggio = "no habilitado"; break;
-case "Inserisci una nuova password":  		$messaggio = "Inserta una nueva contraseña"; break;
-case "Ripeti la password":  			$messaggio = "Repite la contraseña"; break;
-case "Continua":  				$messaggio = "Continúa"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Inserisci una nuova password":  		$messaggio = "Insertar una nueva contraseña"; break;
+case "Ripeti la password":  			$messaggio = "Repetir la contraseña"; break;
+case "Continua":  				$messaggio = "Continuar"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Existe ya</div> un usuario llamado"; break;
 case "Nuova password dell'utente":  		$messaggio = "Nueva contraseña del usuario"; break;
 case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">no</div> insertada correctamente"; break;
@@ -27,7 +27,7 @@ case "Gestione degli utenti di hoteldruid":	$messaggio = "Gestión de usuarios d
 case "N°":  					$messaggio = "N°"; break;
 case "nome":  					$messaggio = "nombre"; break;
 case "login":  					$messaggio = "login"; break;
-case "modifica":  				$messaggio = "modifíca"; break;
+case "modifica":  				$messaggio = "modificar"; break;
 case "password criptata con md5":  		$messaggio = "contraseña encriptada con md5"; break;
 case "password criptata con mcrypt":  		$messaggio = "contraseña encriptada con mcrypt"; break;
 case "password criptata con mhash":  		$messaggio = "contraseña encriptada con mhash"; break;
@@ -35,7 +35,7 @@ case "password":  				$messaggio = "contraseña"; break;
 case "privilegi":  				$messaggio = "privilegios"; break;
 case "Amministratore":  			$messaggio = "Administrador"; break;
 case "Abilitare per usare altri utenti":  	$messaggio = "Habilitar para utilizar otros usuarios"; break;
-case "Modifica gli utenti":  			$messaggio = "Modifíca los usuarios"; break;
+case "Modifica gli utenti":  			$messaggio = "Modificar los usuarios"; break;
 case "Aggiungi":  				$messaggio = "Añadir"; break;
 case "un nuovo utente chiamato":  		$messaggio = "un nuevo usuario llamado"; break;
 case "dell'utente":  				$messaggio = "del usuario"; break;
