@@ -1,6 +1,6 @@
 <?php exit(); ?>
 
-<!--             2016-02-05 14:28:27             -->
+<!--             2016-02-26 14:21:01             -->
 
 <!--  **    SAVE THIS FILE AS hoteld_doc_backup.php     **  -->
 
@@ -8,7 +8,7 @@
 
 
 <backup>
-<versione>2.13</versione>
+<versione>2.14</versione>
 <database>
 <tabella>
 <nometabella>contratti</nometabella>
@@ -127,7 +127,7 @@ Saludos,
 <riga><cmp>6</cmp><cmp>mln_es</cmp><cmp>Estimad[o] Señor[a] [apellido_ec],
 le confirmo que he reservado a su nombre un apartamento[c num_personas_tot!=""] para [num_personas_tot] personas[/c] para el período desde el [fecha_inicial] hasta el [fecha_final]. El precio para dicho período es de [coste_tot_p] [nombre_divisa] (incluyendo costes asociados). Para completar la reserva es necesario pagar por adelantado [fianza_p] [nombre_divisa], puede efectuar este pago siguiendo este enlace:
 
-http://recorrido-modelo-confirma-reserva/mdl_confirma_reserva.php?cognome=[apel_no_esp_ec]&cod_prenota=[codice_prenotazione]
+http://recorrido-modelo-confirma-reserva/mdl_confirma_reserva.php?cn=[apel_no_esp_ec]&cp=[codigo_reserva]
 
 Si el enlace no funcionara correctamente puede intentar utilizar este otro:
 
@@ -165,7 +165,7 @@ Best regards,
 <riga><cmp>6</cmp><cmp>mln_en</cmp><cmp>Dear Mr[Mr] [apellido_ec],
 I confirm you that I have reserved you an apartment[c people_num_tot!=""] for [people_num_tot] people[/c] in the period from [starting_date] to [ending_date]. The price for this period is [price_tot_p] [currency_name] (including cleaning and utilities). In order to complete the reservation you must send a down-payment of [deposit_p] [currency_name], you can pay it following this link:
 
-http://path-confirm-reservation-template/confirm_reservation_tpl.php?cognome=[apel_no_esp_ec]&cod_prenota=[codice_prenotazione]
+http://path-confirm-reservation-template/confirm_reservation_tpl.php?cn=[apel_no_esp_ec]&cp=[codigo_reserva]
 
 If the above link does not work properly for you, try this other one:
 
@@ -173,8 +173,8 @@ http://path-confirm-reservation-template/confirm_reservation_tpl.php
 
 and then insert:
 
-Surname: [surname]
-Reservation code: [reservation_code]
+Surname: [apellido]
+Reservation code: [codigo_reserva]
 
 Please let me know if you have any other question.
 
@@ -706,26 +706,29 @@ Factura n. [numero_progresivo_documento] del [hoy]
 <riga><cmp>154</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?343#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>155</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?331#%?=#%?var#%?nome#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>156</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?332#%?=#%?var#%?cognome#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>157</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?=#%?txt#%?, #%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>158</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?.=#%?var#%?numcivico#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>159</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?citta#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?citta#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>160</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%? (#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>161</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?regione#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>162</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%?)#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>163</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?cap#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?cap#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>164</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?cap#%?!=#%?txt#%?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?txt#%? #%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>165</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?nazione#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>166</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?405#%?=#%?var#%?partita_iva#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>167</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?406#%?=#%?var#%?codice_fiscale#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>168</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?407#%?=#%?var#%?via#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>169</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?408#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>170</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?412#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>171</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?413#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>172</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?414#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>173</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?=#%?txt#%?<img src="#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>174</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?.=#%?var#%?logo_struttura#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>175</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?.=#%?txt#%?" alt="Logo" style="float: right;">#%?txt#%?#%?txt#%?</cmp></riga>
-<riga><cmp>176</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?425#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>157</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?355#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>158</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?=#%?txt#%?, #%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>159</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?numcivico#%?!=#%?txt#%?#@?set#%?355#%?.=#%?var#%?numcivico#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>160</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?325#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>161</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?citta#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?citta#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>162</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%? (#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>163</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?var#%?regione#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>164</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?regione#%?!=#%?txt#%?#@?set#%?325#%?.=#%?txt#%?)#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>165</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?326#%?=#%?txt#%?#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>166</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?cap#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?cap#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>167</cmp><cmp>cond2</cmp><cmp>rpt#@?and#$?cap#%?!=#%?txt#%?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?txt#%? #%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>168</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?nazione#%?!=#%?txt#%?#@?set#%?326#%?.=#%?var#%?nazione#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>169</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?405#%?=#%?var#%?partita_iva#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>170</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?406#%?=#%?var#%?codice_fiscale#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>171</cmp><cmp>cond2</cmp><cmp>rpt#@?#@?set#%?407#%?=#%?var#%?via#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>172</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?408#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>173</cmp><cmp>cond2</cmp><cmp>ind#@?#@?set#%?412#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>174</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?413#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>175</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?414#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>176</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?=#%?txt#%?<img src="#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>177</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?.=#%?var#%?logo_struttura#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>178</cmp><cmp>cond2</cmp><cmp>rpt#@?#$?logo_struttura#%?!=#%?txt#%?#@?set#%?420#%?.=#%?txt#%?" alt="Logo" style="float: right;">#%?txt#%?#%?txt#%?</cmp></riga>
+<riga><cmp>179</cmp><cmp>cond2</cmp><cmp>inr#@?#@?set#%?425#%?=#%?txt#%?0#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>1</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?1#%?=#%?txt#%?s#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>3</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?!=#%?txt#%?f#@?set#%?3#%?=#%?txt#%?il#%?txt#%?#%?txt#%?</cmp></riga>
 <riga><cmp>4</cmp><cmp>cond</cmp><cmp>rpt#@?#$?sesso#%?=#%?txt#%?f#@?set#%?3#%?=#%?txt#%?la#%?txt#%?#%?txt#%?</cmp></riga>
