@@ -30,15 +30,15 @@ case "Il <b>fax</b> verrà cancellato":  	$messaggio = "El <b>fax</b> será borr
 case "L' <b>email</b> verrà cancellata":  	$messaggio = "El <b>correo electrónico</b> será borrado"; break;
 case "Il <b>2° telefono</b> verrà cancellato":	$messaggio = "El <b>segundo teléfono</b> será borrado"; break;
 case "Il <b>3° telefono</b> verrà cancellato":	$messaggio = "El <b>tercer teléfono</b> será borrado"; break;
-case "Continua":  				$messaggio = "Continua"; break;
+case "Continua":  				$messaggio = "Continuar"; break;
 case "Il cliente":  				$messaggio = "El cliente"; break;
 case "è stato modificato":  			$messaggio = "ha sido modificado"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
-case "Modifica i dati del cliente":  		$messaggio = "Modifica los datos del cliente"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
+case "Modifica i dati del cliente":  		$messaggio = "Modificar los datos del cliente"; break;
 case "Cognome":  				$messaggio = "Apellido"; break;
 case "cambia in":  				$messaggio = "cambia a"; break;
 case "Nome":  					$messaggio = "Nombre"; break;
-case "cancella":  				$messaggio = "borra"; break;
+case "cancella":  				$messaggio = "borrar"; break;
 case "Sesso":  					$messaggio = "Sexo"; break;
 case "Data di nascita":  			$messaggio = "Fecha de nacimiento"; break;
 case "Telefono":  				$messaggio = "Teléfono"; break;
