@@ -23,7 +23,7 @@ case "cambia le colonne":  			$messaggio = "cambiar las columnas"; break;
 case "Tabelle dei mesi":  			$messaggio = "Tabla de los meses"; break;
 case "Numero di tabelle del 2° tipo":  		$messaggio = "Número de tablas del 2° tipo"; break;
 case "cambia":  				$messaggio = "cambiar"; break;
-case "Torna al menù principale":  		$messaggio = "Vuelve al menú principal"; break;
+case "Torna al menù principale":  		$messaggio = "Volver al menú principal"; break;
 case "a":  					$messaggio = "a"; break;
 case "La lingua è stata cambiata":  		$messaggio = "El idioma ha sido cambiado"; break;
 case "La valuta è stata cambiata":  		$messaggio = "La divisa ha sido cambiada"; break;
@@ -62,8 +62,8 @@ case "Il numero delle righe della tabella con tutti i clienti è stato cambiato"
 case "Si deve sceliere qualche dato da inserire nella colonna gruppo":	$messaggio = "Hay que escoger algún dato para insertar en la columna grupo"; break;
 case "Si deve inserire il nome della colonna gruppo":	$messaggio = "Hay que insertar el nombre de la columna grupo"; break;
 case "La colonna gruppo è stata aggiunta":  	$messaggio = "La columna grupo ha sido añadida"; break;
-case "Aggiungi una colonna gruppo":  		$messaggio = "Añade una columna grupo"; break;
-case "Aggiungi colonna gruppo":  		$messaggio = "Añade columna grupo"; break;
+case "Aggiungi una colonna gruppo":  		$messaggio = "Añadir una columna grupo"; break;
+case "Aggiungi colonna gruppo":  		$messaggio = "Añadir columna grupo"; break;
 case "chiamata":  				$messaggio = "llamada"; break;
 case "con":  					$messaggio = "con"; break;
 case "colonna gruppo":  			$messaggio = "columna grupo"; break;
@@ -98,8 +98,8 @@ case "Gestione utenti":  			$messaggio = "Gestión de usuarios"; break;
 case "Personalizzazioni dell'utente":  		$messaggio = "Personalizaciones del usuario"; break;
 case "Cambia":  				$messaggio = "Cambiar"; break;
 case "quelle di":  				$messaggio = "las de"; break;
-case "Importa i nomi dei documenti":  		$messaggio = "Importa los nombres de los documentos"; break;
-case "Importa":  				$messaggio = "Importa"; break;
+case "Importa i nomi dei documenti":  		$messaggio = "Importar los nombres de los documentos"; break;
+case "Importa":  				$messaggio = "Importar"; break;
 case "dell'utente":  				$messaggio = "del usuario"; break;
 case "I minuti di durata di sessioni e transazioni sono stati cambiati":	$messaggio = "Los minutos de duración de sesiones y transacciones han sido cambiados"; break;
 case "Le ore di anticipo dell'inizio delle prenotazioni sono state cambiate":	$messaggio = "Las horas de antelación del principio de las reservas han sido cambiadas"; break;
@@ -148,7 +148,7 @@ case "Parole da sostituire":  			$messaggio = "Palabras a reemplazar"; break;
 case "La parola da sostituire è stata aggiunta":	$messaggio = "La palabra a reemplazar ha sido añadida"; break;
 case "La parola da sostituire è stata eliminata":	$messaggio = "La palabra a reemplazar ha sido eliminada"; break;
 case "modifica il documento":  			$messaggio = "modifica el documento"; break;
-case "Aggiungi ai documenti":  			$messaggio = "Añade a los documentos"; break;
+case "Aggiungi ai documenti":  			$messaggio = "Añadir a los documentos"; break;
 case "variabili personalizzate":  		$messaggio = "variables personalizadas"; break;
 case "Cambia il numero dei documenti":  	$messaggio = "Cambiar el número de documentos"; break;
 case "Il numero di documenti è stato cambiato":	$messaggio = "El número de documentos ha sido cambiado"; break;
@@ -223,7 +223,7 @@ case "Log delle query di modifica degli utenti normali disattivato":	$messaggio
 case "Log delle query di modifica degli utenti normali attivato":	$messaggio = "Log de las queries de modificación de los usuarios normales activado"; break;
 case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Alinear la disponibilidad con la fecha de llegada?"; break;
 case "L'allineamento dei giorni con la disponibilità nella tabella dei mesi è stato cambiato":	$messaggio = "La alineación de los días con la disponibilidad en la tabla de los meses ha sido cambiada"; break;
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Allineare la disponibilità con le date di arrivo potrebbe generare confusione ed errori sulle date di partenza, si è sicuri di voler continuare?":	$messaggio = "Alinear la disponibilidad con las fechas de llegada podría generar confusión y errores sobre las fechas de salida, está seguro de querer continuar?"; break;
 case "Documenti di identità":  			$messaggio = "Documentos de identidad"; break;
 case "Tipo di documento di identità eliminato":	$messaggio = "Tipo de documento de identidad eliminado"; break;
