@@ -2,7 +2,7 @@
 
 switch ($messaggio) {
 
-case "Torna indietro":  			$messaggio = "Vuelve atrás"; break;
+case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Privilegi dell'utente":  			$messaggio = "Privilegos del usuario"; break;
 case "Privilegi <b>globali</b>":  		$messaggio = "Privilegos <b>globales</b>"; break;
 case "Modifica delle proprie personalizzazioni":	$messaggio = "Modificación de las proprias personalizaciones"; break;
@@ -18,12 +18,12 @@ case "Inserire in tutti i cognomi dei clienti inseriti da questo utente":	$messa
 case "Un prefisso":  				$messaggio = "Un prefijo"; break;
 case "Un suffisso":  				$messaggio = "Un sufijo"; break;
 case "Niente":  				$messaggio = "Nada"; break;
-case "Modifica i privilegi globali":  		$messaggio = "Modifica los privilegios globales"; break;
+case "Modifica i privilegi globali":  		$messaggio = "Modificar los privilegios globales"; break;
 case "Privilegi per l'anno":			$messaggio = "Privilegios para el año"; break;
 case "Anno disattivato":  			$messaggio = "Año Inhabilitado"; break;
-case "Attiva":  				$messaggio = "Habilita"; break;
+case "Attiva":  				$messaggio = "Habilitar"; break;
 case "Anno attivato":  				$messaggio = "Año habilitado"; break;
-case "Disattiva":  				$messaggio = "Inhabilita"; break;
+case "Disattiva":  				$messaggio = "Inhabilitar"; break;
 case "Prenotazioni inseribili solo nei periodi della regola di assegnazione 1 con le motivazioni selezionate":	$messaggio = "Reservas insertables solo en los períodos de la regla de asignación 1 con motivaciones seleccionadas"; break;
 case "nessuna":  				$messaggio = "ninguna"; break;
 case "Applica la regola 1":  			$messaggio = "Aplica la regla 1"; break;
@@ -98,7 +98,7 @@ case "Possibilità di vedere la <i>tabella con i periodi e le tariffe</i>":	$mes
 case "Solo con tariffe consentite":  		$messaggio = "Solo con tarifas permitidas"; break;
 case "Possibilità di vedere la <i>tabella con le regole di assegnazione</i>":	$messaggio = "Posibilidad de ver la <i>tabla con las reglas de asignación</i>"; break;
 case "Solo con regole consentite":  		$messaggio = "Solo con reglas permitidas"; break;
-case "Modifica i privilegi dell'anno":  	$messaggio = "Modifica los privilegios del año"; break;
+case "Modifica i privilegi dell'anno":  	$messaggio = "Modificar los privilegios del año"; break;
 case "Testo del prefisso/suffisso dei clienti":	$messaggio = "Texto del prefijo/sufijo de los clientes"; break;
 case "Si deve inserire il <div style=\"display: inline; color: red;\">prefisso/suffisso</div> da utilizzare per i clienti dell'utente":	$messaggio = "Hay que insertar el <div style=\"display: inline; color: red;\">prefijo/sufijo</div> a utilizar para los clientes del usuario"; break;
 case "L'utente":  				$messaggio = "El usuario"; break;
