@@ -47,7 +47,7 @@ case "Tutte le entrate del":  			$messaggio = "Todas las entradas del"; break;
 case "Natura_entrata":  			$messaggio = "Razón_de_la_entrada"; break;
 case "cancella":  				$messaggio = "borrar"; break;
 case "entrata presa dalle prenotazioni":  	$messaggio = "entrada cogida de las reservas"; break;
-case "Inserisci nuove spese o entrate":  	$messaggio = "Insera nuevos gastos o entradas"; break;
+case "Inserisci nuove spese o entrate":  	$messaggio = "Insertar nuevos gastos o entradas"; break;
 case "Storia entrate-uscite prenotazioni":  	$messaggio = "Historial de pagos de las reservas"; break;
 case "Sei sicuro di voler cancellare il costo aggiuntivo":	$messaggio = "Estás seguro de querer borrar el coste añadido"; break;
 case "Il costo aggiuntivo":  			$messaggio = "El coste añadido"; break;
@@ -88,7 +88,7 @@ case "percentuale":  				$messaggio = "porcentaje"; break;
 case "% arrotondato_a_":  			$messaggio = "% redondeado_a_"; break;
 case "Caparre, commissioni e tasse del":  	$messaggio = "Fianzas, comisiones y tasas del"; break;
 case "Arrotondato_a":  				$messaggio = "Redondeado_a"; break;
-case "Vai alla pagina di inserzione prezzi":  	$messaggio = "Vé a la página de inserción de precios"; break;
+case "Vai alla pagina di inserzione prezzi":  	$messaggio = "Ir a la página de inserción de precios"; break;
 case "chiamati":  				$messaggio = "llamados"; break;
 case "Cerca i clienti con cognome o email":  	$messaggio = "Busca los clientes con apellido o email"; break;
 case "Tabella con tutti i clienti":  		$messaggio = "Tabla con todos los clientes"; break;
@@ -116,9 +116,9 @@ case "Tabella con le regole di assegnazione 1 del":	$messaggio = "Tabla con las
 case "Motivazione":  				$messaggio = "Motivación"; break;
 case "Tabella con le regole di assegnazione 2 del":	$messaggio = "Tabla con las reglas de asignación 2 del"; break;
 case "Tariffa":  				$messaggio = "Tarifa"; break;
-case "Inserisci nuove regole":  		$messaggio = "Inserta nuevas reglas"; break;
+case "Inserisci nuove regole":  		$messaggio = "Insertar nuevas reglas"; break;
 case "Il numero inserito esiste già":  		$messaggio = "El número insertado ya existe"; break;
-case "Continua":  				$messaggio = "Continua"; break;
+case "Continua":  				$messaggio = "Continuar"; break;
 case "Torna indietro":  			$messaggio = "Volver atrás"; break;
 case "Casa":  					$messaggio = "Casa"; break;
 case "Piano":  					$messaggio = "Piso"; break;
