@@ -180,6 +180,8 @@ $app_orig_prenota_id = $app_prenota_id;
 $app_agenzia = esegui_query("select * from $tableregole where app_agenzia != '' and (motivazione2 != 'x' or motivazione2 is NULL) ");
 $regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''");
 $dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
+unset($dati_r2);
+dati_regole2($dati_r2,$app_regola2_predef,"","","",$id_periodo_corr,$tipo_periodi,$anno,$tableregole);
 
 unlock_tabelle($tabelle_lock);
 
@@ -188,7 +190,10 @@ $num_regole2 = numlin_query($regole2);
 unset($app_regola2_orig);
 for ($num1 = 0 ; $num1 < $num_regole2 ; $num1++) {
 $numtariffa_regola2 = str_replace("tariffa","",risul_query($regole2,$num1,'tariffa_per_app'));
-if ($tariffe_mostra[$numtariffa_regola2] == "SI") $app_regola2_orig[$numtariffa_regola2] = risul_query($regole2,$num1,'motivazione');
+if ($tariffe_mostra[$numtariffa_regola2] == "SI") {
+$app_regola2_orig[$numtariffa_regola2] = risul_query($regole2,$num1,'motivazione');
+if ($dati_r2['napp']["tariffa$numtariffa_regola2"]) $app_regola2_orig['napp'][$numtariffa_regola2] = $dati_r2['napp']["tariffa$numtariffa_regola2"];
+} # fine if ($tariffe_mostra[$numtariffa_regola2] == "SI")
 } # fine for $num1
 
 $colonna_destra_tab_disp = "NO";
