@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2009 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -64,7 +64,8 @@ echo "<form method=\"post\" action=\"crea_modelli.php\"><div>
 <input type=\"hidden\" name=\"lingua_modello\" value=\"$lingua_modello\">
 <input type=\"hidden\" name=\"perc_cart_mod_sel\" value=\"$perc_cart_mod_sel\">
 
-<h5>".mext_rat("Pagina della tabella con le tariffe",$pag)."</h5><br><br>
+<div style=\"height: 4px;\"></div>
+<h5 id=\"h_rat\"><span>".mext_rat("Pagina della tabella con le tariffe",$pag)."</span></h5><br><br>
 <table><tr><td valign=\"top\">
 ".mext_rat("Mostra tariffe",$pag)."</td><td>";
 if (!$num_periodi_date or controlla_num_pos($num_periodi_date) == "NO") $num_periodi_date = 1;
@@ -262,7 +263,7 @@ $num_colori = count($colori_tema);
 for ($num2 = 1 ; $num2 <= $num_colori ; $num2++) {
 $colore_corr = $colori_tema[$num2]['default'];
 if ($sel and ${"colore_tema_".$num2}) $colore_corr = ${"colore_tema_".$num2};
-$js_opz_tema .= "".mex("Colore del tema",$pag)." \"".$template_theme_name[$num1]."\" ".mex("per",$pag)." \"".$colori_tema[$num2]['name']."\":\\
+$js_opz_tema .= "".mex("Colore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$colori_tema[$num2]['name']."\":\\
  <input type=\"text\" name=\"colore_tema_$num2\" id=\"coltxt$num2\" size=\"8\" value=\"$colore_corr\" onchange=\"agg_colore_sel_txt($num2)\">\\
 <select id=\"colsel$num2\" onchange=\"agg_colore_sel($num2)\" style=\"width: 80px; background-color: $colore_corr\"><option value=\"$colore_corr\" style=\"background-color: $colore_corr\">&nbsp;<\/option>'+options_colori+'<\/select><br>";
 } # fine for $num2
@@ -271,7 +272,7 @@ $num_valori = count($valori_tema);
 for ($num2 = 1 ; $num2 <= $num_valori ; $num2++) {
 $valore_corr = $valori_tema[$num2]['default'];
 if ($sel and $modello_esistente == "SI") $valore_corr = ${"valore_tema_".$num2};
-$js_opz_tema .= "".mex("Valore del tema",$pag)." \"".$template_theme_name[$num1]."\" ".mex("per",$pag)." \"".$valori_tema[$num2]['name']."\":\\
+$js_opz_tema .= "".mex("Valore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$valori_tema[$num2]['name']."\":\\
  <input type=\"text\" name=\"valore_tema_$num2\" id=\"valtema$num2\" size=\"24\" value=\"$valore_corr\"><br>";
 } # fine for $num2
 $js_opz_tema .= "<\/td><\/tr><\/table>';
@@ -373,13 +374,13 @@ for ($num_fr = 0 ; $num_fr < $num_frasi ; $num_fr++) echo "<input type=\"hidden\
 } # fine elseif ($modello_esistente == "SI")
 
 echo "<br><div style=\"text-align: center;\"><input type=\"hidden\" name=\"$template_name\" value=\"SI\">
-<input class=\"sbutton\" type=\"submit\" value=\"".mext_rat("Crea la pagina con la tabella delle tariffe",$pag)."\">
+<button class=\"rate\" type=\"submit\"><div>".mext_rat("Crea la pagina con la tabella delle tariffe",$pag)."</div></button>
 </div></div></form><br>
 <hr style=\"width: 95%\"><br><div style=\"text-align: center;\">
 <form method=\"post\" action=\"crea_modelli.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input class=\"sbutton\" type=\"submit\" name=\"indietro\" value=\"".mex("Torna indietro",$pag)."\">
+<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form><br></div>";
 
 
