@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -125,6 +125,8 @@ $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $periodi = esegui_query("select * from $tableperiodi order by idperiodi");
 $rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 or idntariffe = 2 order by idntariffe ");
 $dati_tariffe = dati_tariffe($tablenometariffe,"","",$tableregole);
+$dati_r2 = "";
+dati_regole2($dati_r2,$app_regola2_predef,"","","",$id_periodo_corrente,$tipo_periodi,$anno,$tableregole);
 $dati_ca = dati_costi_agg_ntariffe($tablenometariffe,$dati_tariffe['num'],"NO");
 
 unlock_tabelle($tabelle_lock);
@@ -172,14 +174,24 @@ for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 if ($tariffe_mostra[${"numtariffa".$num1}] == "SI") {
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] = (double) risul_query($periodi,$inizioperiodi_id[$num_p],$tariffa[$num1]);
 $tariffap_colonna_periodo[$num1][$num_colonne_periodi] = (double) risul_query($periodi,$inizioperiodi_id[$num_p],$tariffa[$num1]."p");
+if ($dati_r2['napp'][$tariffa[$num1]] > 1) {
+$tariffa_colonna_periodo[$num1][$num_colonne_periodi] = $tariffa_colonna_periodo[$num1][$num_colonne_periodi] * (double) $dati_r2['napp'][$tariffa[$num1]];
+$tariffap_colonna_periodo[$num1][$num_colonne_periodi] = $tariffap_colonna_periodo[$num1][$num_colonne_periodi] * (double) $dati_r2['napp'][$tariffa[$num1]];
+} # fine if ($dati_r2['napp'][$tariffa[$num1]] > 1)
 if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + 1)]) {
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] = "c";
 $tariffap_colonna_periodo[$num1][$num_colonne_periodi] = "c";
 } # fine if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + 1)])
 for ($num_i = 1 ; $num_i < $intervalloperiodi[$num_p] ; $num_i++) {
 if ($tariffa_colonna_periodo[$num1][$num_colonne_periodi] == "c") break;
-$tariffa_colonna_periodo[$num1][$num_colonne_periodi] += (double) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]);
-$tariffap_colonna_periodo[$num1][$num_colonne_periodi] += (double) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]."p");
+$tar_corr = (double) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]);
+$tarp_corr = (double) risul_query($periodi,($inizioperiodi_id[$num_p] + $num_i),$tariffa[$num1]."p");
+if ($dati_r2['napp'][$tariffa[$num1]] > 1) {
+$tar_corr = $tar_corr * (double) $dati_r2['napp'][$tariffa[$num1]];
+$tarp_corr = $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num1]];
+} # fine if ($dati_r2['napp'][$tariffa[$num1]] > 1)
+$tariffa_colonna_periodo[$num1][$num_colonne_periodi] += $tar_corr;
+$tariffap_colonna_periodo[$num1][$num_colonne_periodi] += $tarp_corr;
 if ($dati_tariffe[$tariffa[$num1]]['chiusa'][($inizioperiodi_id[$num_p] + $num_i + 1)]) {
 $tariffa_colonna_periodo[$num1][$num_colonne_periodi] = "c";
 $tariffap_colonna_periodo[$num1][$num_colonne_periodi] = "c";
@@ -194,14 +206,24 @@ for ($num2 = 1 ; $num2 <= $num_tariffe_mostra ; $num2++) {
 if ($tariffe_mostra[${"numtariffa".$num2}] == "SI") {
 ${$tariffa[$num2]} = (double) risul_query($periodi,$num1,$tariffa[$num2]);
 ${$tariffa[$num2]."p"} = (double) risul_query($periodi,$num1,$tariffa[$num2]."p");
+if ($dati_r2['napp'][$tariffa[$num2]] > 1) {
+${$tariffa[$num2]} = ${$tariffa[$num2]} * (double) $dati_r2['napp'][$tariffa[$num2]];
+${$tariffa[$num2]."p"} = ${$tariffa[$num2]."p"} * (double) $dati_r2['napp'][$tariffa[$num2]];
+} # fine if ($dati_r2['napp'][$tariffa[$num2]] > 1)
 if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + 1)]) {
 ${$tariffa[$num2]} = "c";
 ${$tariffa[$num2]."p"} = "c";
 } # fine if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + 1)])
 for ($num_i = 1 ; $num_i < $intervalloperiodi[$num_p] ; $num_i++) {
 if (${$tariffa[$num2]} == "c") break;
-${$tariffa[$num2]} += (double) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]);
-${$tariffa[$num2]."p"} += (double) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]."p");
+$tar_corr = (double) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]);
+$tarp_corr = (double) risul_query($periodi,($num1 + $num_i),$tariffa[$num2]."p");
+if ($dati_r2['napp'][$tariffa[$num2]] > 1) {
+$tar_corr = $tar_corr * (double) $dati_r2['napp'][$tariffa[$num2]];
+$tarp_corr = $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num2]];
+} # fine if ($dati_r2['napp'][$tariffa[$num2]] > 1)
+${$tariffa[$num2]} += $tar_corr;
+${$tariffa[$num2]."p"} += $tarp_corr;
 if ($dati_tariffe[$tariffa[$num2]]['chiusa'][($num1 + $num_i + 1)]) {
 ${$tariffa[$num2]} = "c";
 ${$tariffa[$num2]."p"} = "c";
