@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2010 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -38,13 +38,16 @@ $template_theme_colors[1][3]['name'] = "background 2";
 $template_theme_colors[1][3]['default'] = "#ebebeb";
 $template_theme_values[1][1]['name'] = mex("URL della home",$pag);
 $template_theme_values[1][1]['default'] = $dati_struttura[4];
-$template_theme_values[1][1]['replace'] = "<div style=\"width: 100%; padding: 10px 0 10px 20px; margin: 0; border-bottom: 2px solid [theme_color_1]; background-color: [theme_color_3];\"><a href=\"[theme_value_1]\" style=\"color: [theme_color_1];\" target=\"_top\">[theme_value_2]</a></div>";
+$template_theme_values[1][1]['replace'] = "<div class=\"homebox\"><a href=\"[theme_value_1]\" style=\"color: [theme_color_1];\" target=\"_top\">[theme_value_2]</a></div>";
 $template_theme_values[1][2]['name'] = mex("URL del logo",$pag);
 $template_theme_values[1][2]['default'] = $dati_struttura[15];
 $template_theme_values[1][2]['replace'] = "<img style=\"text-decoration: none; border: 0px;\" src=\"[theme_value_2]\" alt=\"[theme_value_3]\">";
 $template_theme_values[1][2]['null'] = "[theme_value_3]";
 $template_theme_values[1][3]['name'] = mex("Torna alla HOME",$pag);
 $template_theme_values[1][3]['default'] = mex2("Torna alla HOME",$pag,$lingua_modello);
+$template_theme_values[1][4]['name'] = mex("URL file css",$pag);
+$template_theme_values[1][4]['default'] = "";
+$template_theme_values[1][4]['replace'] = "<link rel=\"stylesheet\" type=\"text/css\" href=\"[theme_value_4]\" media=\"all\">";
 $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
         \"http://www.w3.org/TR/html4/strict.dtd\">
 <html>
@@ -52,17 +55,20 @@ $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\" >
 <title> $nome_file </title>
 <style type=\"text/css\">
+ div.homebox { width: 100%; padding: 10px 0 10px 20px; margin: 0; border-bottom: 2px solid [theme_color_1]; background-color: [theme_color_3]; }
+ div.mainbox { text-align: center; padding: 10px; }
  .rates { background-color: [theme_color_3]; border-radius: 10px; }
  .rates tr:first-child td:first-child { border-top-left-radius: 10px; }
  .rates tr:first-child td:last-child { border-top-right-radius: 10px; }
  .rates tr:last-child td:first-child { border-bottom-left-radius: 10px; }
  .rates tr:last-child td:last-child { border-bottom-right-radius: 10px; }
 </style>
+[theme_value_4]
 </head>
 <body style=\"background-color: [theme_color_2]; color: [theme_color_1]; padding: 0; margin: 0;\">
 [theme_value_1]
 
-<div style=\"text-align: center; padding: 10px;\"><big><big>
+<div class=\"mainbox\"><big><big>
 ".mext_rat("Tabella Tariffe",$pag,$lingua_modello)."</big></big>
 <br><br>";
 $template_theme_html_post[1] = "
