@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2011 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2016 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -38,13 +38,16 @@ $template_theme_colors[1][3]['name'] = "background 2";
 $template_theme_colors[1][3]['default'] = "#ebebeb";
 $template_theme_values[1][1]['name'] = "URL home";
 $template_theme_values[1][1]['default'] = $dati_struttura[4];
-$template_theme_values[1][1]['replace'] = "<div style=\"width: 100%; padding: 10px 0 10px 20px; margin: 0; border-bottom: 2px solid [theme_color_1]; background-color: [theme_color_3];\"><a href=\"[theme_value_1]\" style=\"color: [theme_color_1];\" target=\"_top\">[theme_value_2]</a></div>";
+$template_theme_values[1][1]['replace'] = "<div class=\"homebox\"><a href=\"[theme_value_1]\" style=\"color: [theme_color_1];\" target=\"_top\">[theme_value_2]</a></div>";
 $template_theme_values[1][2]['name'] = "URL logo";
 $template_theme_values[1][2]['default'] = $dati_struttura[15];
 $template_theme_values[1][2]['replace'] = "<img style=\"text-decoration: none; border: 0px;\" src=\"[theme_value_2]\" alt=\"[theme_value_3]\">";
 $template_theme_values[1][2]['null'] = "[theme_value_3]";
 $template_theme_values[1][3]['name'] = "home";
 $template_theme_values[1][3]['default'] = "".mex2("Torna alla HOME",$pag,$lingua_modello)."";
+$template_theme_values[1][4]['name'] = mex("URL file css",$pag);
+$template_theme_values[1][4]['default'] = "";
+$template_theme_values[1][4]['replace'] = "<link rel=\"stylesheet\" type=\"text/css\" href=\"[theme_value_4]\" media=\"all\">";
 $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
         \"http://www.w3.org/TR/html4/strict.dtd\">
 <html>
@@ -52,22 +55,30 @@ $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN
 <meta http-equiv=\"Content-Type\" content=\"text/html;charset=utf-8\">
 <title> $nome_file </title>
 <style type=\"text/css\">
+ div.homebox { width: 100%; padding: 10px 0 10px 20px; margin: 0; border-bottom: 2px solid [theme_color_1]; background-color: [theme_color_3]; }
+ div.mainbox { text-align: center; padding: 10px; }
+ table.formframe { margin-left: auto;  margin-right: auto; background-color: [theme_color_3]; border-radius: 14px; }
+ table.formframe td { border-radius: 14px; }
+ table.formcont { text-align: left; margin-left: 0; }
+ table.formcont td { border: 0; border-radius: 0; }
+ table.tab_disp td { border: 1px solid #444444; }
  .tab_disp {font-size:70%;}
  .t_book {  border-radius: 8px; }
  .t_book td {  border-radius: 8px; }
  div.agreem { max-width: 600px; border: 1px solid black; padding: 3px; }
  select { background-color: #ffffff; }
 </style>
+[theme_value_4]
 </head>
 <body style=\"background-color: [theme_color_2]; color: [theme_color_1]; padding: 0; margin: 0;\">
 [theme_value_1]
 
-<div style=\"text-align: center; padding: 10px;\"><big><big>
+<div class=\"mainbox\"><big><big>
 ".mex2("Controlla la disponibilità",$pag,$lingua_modello)."</big></big><br><br>
 
-<table style=\"margin-left: auto;  margin-right: auto; background-color: [theme_color_3]; border-radius: 14px;\" border=1 cellspacing=0 cellpadding=16>
-<tr><td style=\" border-radius: 14px;\">
-<table style=\"text-align: left; margin-left: 0;\" border=0 cellspacing=0 cellpadding=0><tr><td>
+<table class=\"formframe\" border=1 cellspacing=0 cellpadding=16>
+<tr><td>
+<table class=\"formcont\" cellspacing=0 cellpadding=0><tr><td>
 ";
 $template_theme_html_post[1] = "
 <br></td></tr></table>
