@@ -504,6 +504,11 @@ unlock_tabelle($tabelle_lock);
 
 if ($num_prenotazioni > 0) {
 if (!function_exists('dati_costi_agg_prenota')) include("./includes/funzioni_costi_agg.php");
+$colori_tab_mesi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'colori_tab_mesi' and idutente = '$id_utente'");
+$colori_tab_mesi = explode(",",risul_query($colori_tab_mesi,0,'valpersonalizza'));
+$colore_giallo = $colori_tab_mesi[1];
+$colore_arancione = $colori_tab_mesi[2];
+$colore_rosso = $colori_tab_mesi[3];
 $fr_Appartamento = mex("Appartamento",'unit.php');
 $stile_data = stile_data();
 if (strlen($fr_Appartamento) > 4) $fr_Appartamento = substr($fr_Appartamento,0,3).".";
@@ -581,9 +586,9 @@ $confermato = risul_query($prenotazioni,$num1,'conferma');
 $confermato = substr($confermato,0,1);
 $colore = "";
 if ($pagato < $costo_tot) {
-$colore = "#FFEE22"; #giallo
-if ($pagato < $caparra) $colore = "#FF9900"; #arancione
-if ($confermato != "S") $colore = "#CC0000"; # rosso
+$colore = $colore_giallo; #giallo
+if ($pagato < $caparra) $colore = $colore_arancione; #arancione
+if ($confermato != "S") $colore = $colore_rosso; # rosso
 } # fine if ($pagato < $costo_tot)
 
 $link_modifica = "SI";
