@@ -39,7 +39,9 @@ elseif (!@is_file(C_DATI_PATH."/selectperiodi$anno.1.php") and @is_file(C_DATI_P
 } # fine if (!isset($anno))
 } # fine if (!isset($anno))
 include("./includes/funzioni.php");
+if (function_exists('ini_set')) @ini_set('opcache.enable',0);
 $tableutenti = $PHPR_TAB_PRE."utenti";
+$tablegruppi = $PHPR_TAB_PRE."gruppi";
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 $tablesessioni = $PHPR_TAB_PRE."sessioni";
@@ -280,9 +282,38 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./inizio.php\"><di
 } # fine if ($azione_ic == "SI" or $id_utente_azione_ic)
 
 
+
 if ($priv_crea_interconnessioni == "s") {
 
 
+$lista_tutti_app = "";
+$appartamenti = esegui_query("select * from $tableappartamenti order by idappartamenti");
+$num_appartamenti = numlin_query($appartamenti);
+for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
+$idapp = risul_query($appartamenti,$num1,'idappartamenti');
+$maxocc = risul_query($appartamenti,$num1,'maxoccupanti');
+$lista_tutti_app .= "$idapp,";
+} # fine for $num1
+$lista_tutti_app = substr($lista_tutti_app,0,-1);
+
+unset($lista_regola2);
+$regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''");
+$num_regole2 = numlin_query($regole2);
+for ($num1 = 0 ; $num1 < $num_regole2 ; $num1++) {
+$tariffa = risul_query($regole2,$num1,'tariffa_per_app');
+$lista_app = risul_query($regole2,$num1,'motivazione');
+if (strcmp($lista_app,"")) {
+$lista_regola2[$tariffa] = explode(",",$lista_app);
+$lista_regola2[$tariffa]['num'] = count($lista_regola2[$tariffa]);
+} # fine if (strcmp($lista_app,""))
+else $lista_regola2[$tariffa]['num'] = 0;
+$lista_regola2[$tariffa]['txt'] = $lista_app;
+$lista_app2 = risul_query($regole2,$num1,'motivazione2');
+$lista_regola2[$tariffa]['txt2'] = $lista_app;
+if ($lista_app and $lista_app2) $lista_regola2[$tariffa]['txt2'] .= ",$lista_app2";
+} # fine for $num1
+
+
 
 if ($modifica_interconnessione == "SI") {
 $mostra_form_iniziale = "NO";
@@ -489,21 +520,30 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"./interconnessioni
 } # fine else if (@is_file(C_DATI_PATH."/dati_subordinazione.php"))
 
 $interconn_dir = opendir("./includes/interconnect/");
+$interconnessioni = array();
 while ($mod_ext = readdir($interconn_dir)) {
-if ($mod_ext != "." and $mod_ext != ".." and @is_dir("./includes/interconnect/$mod_ext")) {
+if ($mod_ext != "." and $mod_ext != ".." and @is_dir("./includes/interconnect/$mod_ext")) $interconnessioni[$mod_ext] = 1;
+} # fine while ($mod_ext = readdir($interconn_dir))
+ksort($interconnessioni);
+reset($interconnessioni);
+while (list($mod_ext,$val_i) = each($interconnessioni)) {
 include("./includes/interconnect/$mod_ext/name.php");
 if ($interconnection_name_show[$lingua_mex]) $titolo = $interconnection_name_show[$lingua_mex];
 else $titolo = $interconnection_name_show['en'];
 echo "<hr style=\"width: 95%\"><div style=\"text-align: center;\"><b>$titolo</b></div><br>";
 include("./includes/interconnect/$mod_ext/form.php");
-} # fine if ($modello_ext != "." and $modello_ext != ".." and...
-} # fine while ($mod_ext = readdir($interconn_dir))
+} # fine while (list($mod_ext,$val_i) = each($interconnessioni))
 closedir($interconn_dir);
 
 
 $templates_dir = opendir("./includes/templates/");
+$modelli = array();
 while ($modello_ext = readdir($templates_dir)) {
-if ($modello_ext != "." and $modello_ext != ".." and @is_dir("./includes/templates/$modello_ext")) {
+if ($modello_ext != "." and $modello_ext != ".." and @is_dir("./includes/templates/$modello_ext")) $modelli[$modello_ext] = 1;
+} # fine while ($file = readdir($lang_dig))
+ksort($modelli);
+reset($modelli);
+while (list($modello_ext,$val_i) = each($modelli)) {
 include("./includes/templates/$modello_ext/name.php");
 if ($template_name_show['tpl_type'] == "interconnection") {
 if (!function_exists('mex2')) {
@@ -527,8 +567,7 @@ else $titolo = $template_name_show['en'];
 echo "<hr style=\"width: 95%\"><div style=\"text-align: center;\"><b>$titolo</b></div><br>";
 include("./includes/templates/$modello_ext/form.php");
 } # fine if ($template_name_show['tpl_type'] == "interconnection")
-} # fine if ($modello_ext != "." and $modello_ext != ".." and...
-} # fine while ($file = readdir($lang_dig))
+} # fine while (list($modello_ext,$val_i) = each($modelli))
 closedir($templates_dir);
 
 
