@@ -222,7 +222,7 @@ echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"continua\" value=\"SI\">
 <input type=\"hidden\" name=\"elimina_messaggio\" value=\"SI\">
 ".mex("Si è sicuri di voler eliminare la richiesta di prenotazione di",$pag)." $mittente ".mex("non ancora inserita?",$pag)."
-<input class=\"sbutton\" type=\"submit\" value=\"".mex("SI",$pag)."\">
+<button class=\"canc\" type=\"submit\"><div>".mex("SI",$pag)."</div></button>
 </div></form><br><br>";
 } # fine if ($tipo_messaggio == "rprenota" and $dati_messaggio1 == "da_inserire" and !$continua)
 if ($continua != "NO") {
@@ -260,7 +260,7 @@ if ($prima_dopo == "dopo") echo mex("dopo il",$pag);
 echo " <b>".formatta_data($data_arrivo,$stile_data)."</b>";
 } # fine if ($data_arrivo)
 echo "?
-<input class=\"sbutton\" type=\"submit\" value=\"".mex("SI",$pag)."\">
+<button class=\"canc\" type=\"submit\"><div>".mex("SI",$pag)."</div></button>
 </div></form><br><br>";
 } # fine if ($continua != "SI")
 else {
@@ -598,7 +598,7 @@ if ($mostra_form_iniziale == "NO") {
 echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input class=\"sbutton\" type=\"submit\" name=\"torna\" value=\"".mex("Torna indietro",$pag)."\">
+<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form>";
 } # fine if ($mostra_form_iniziale == "NO")
 
@@ -614,13 +614,13 @@ if ($mostra_form_iniziale != "NO") {
 if (function_exists('imap_open')) {
 $server_email_tab_messaggi = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'server_email_tab_messaggi' and idutente = '$id_utente' ");
 if (numlin_query($server_email_tab_messaggi)) {
-$server = explode("#@#",risul_query($server_email_tab_messaggi,0,'valpersonalizza'));
+#$server = explode("#@#",risul_query($server_email_tab_messaggi,0,'valpersonalizza'));
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div style=\"line-height:160%\">
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
 <input type=\"hidden\" name=\"scarica_mess\" value=\"1\">
-<button class=\"deml\" type=\"submit\"><div style=\"font-size: 70%;\">".mex("Scarica messaggi email",$pag)."</div></button
+<button class=\"deml\" type=\"submit\"><div style=\"font-size: 70%;\">".mex("Scarica messaggi email",$pag)."</div></button>
 </div></form>";
 } # fine if (numlin_query($server_email_tab_messaggi))
 } # fine if (function_exists('imap_open'))
@@ -809,7 +809,9 @@ $nummoltiplica_ca_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio13
 $id_periodi_costo_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio14'));
 $dati_calcolati_dt = explode(";",risul_query($messaggi,$num1,'dati_messaggio16'));
 $anno_prenota_dt = risul_query($messaggi,$num1,'dati_messaggio18');
-$origine_prenota_dt = risul_query($messaggi,$num1,'dati_messaggio19');
+$origine_prenota_dt = explode(">",risul_query($messaggi,$num1,'dati_messaggio19'));
+$prenota_vicine_dt = $origine_prenota_dt[1];
+$origine_prenota_dt = $origine_prenota_dt[0];
 $aggiunta_testo_dt = risul_query($messaggi,$num1,'dati_messaggio20');
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 $inizioperiodo[$n_t] = aggslashdb($inizioperiodo_dt[($n_t - 1)]);
@@ -885,6 +887,8 @@ $commenti_pers = explode(">",$dati_richiedente_dt[21]);
 $num_commenti_pers = count($commenti_pers);
 if ($num_commenti_pers < 1) $num_commenti_pers = 1;
 $campi_pers_clienti = $dati_richiedente_dt[22];
+$codfiscale = $dati_richiedente_dt[23];
+$partitaiva = $dati_richiedente_dt[24];
 
 if ($stato_prenota == "da_inserire") {
 if ($priv_ins_nuove_prenota == "s" and $inizioperiodo[1]) {
@@ -895,7 +899,8 @@ $tasto_prenota = "<form accept-charset=\"utf-8\" method=\"post\" action=\"prenot
 <input type=\"hidden\" name=\"cognome\" value=\"$cognome_richiedente\">
 <input type=\"hidden\" name=\"nome\" value=\"$nome_richiedente\">";
 $tasto_prenota .= "<input type=\"hidden\" name=\"mos_tut_dat\" value=\"SI\">
-<input type=\"hidden\" name=\"num_tipologie\" value=\"$num_tipologie\">";
+<input type=\"hidden\" name=\"num_tipologie\" value=\"$num_tipologie\">
+<input type=\"hidden\" name=\"prenota_vicine\" value=\"$prenota_vicine_dt\">";
 for ($n_t = 1 ; $n_t <= $num_tipologie ; $n_t++) {
 $tasto_prenota .= "<input type=\"hidden\" name=\"inizioperiodo$n_t\" value=\"".$idinizioperiodo[$n_t]."\">
 <input type=\"hidden\" name=\"fineperiodo$n_t\" value=\"".$idfineperiodo[$n_t]."\">
@@ -985,6 +990,8 @@ $tasto_contr .= "<input type=\"hidden\" name=\"cognome_$n_c\" value=\"$cognome_r
 <input type=\"hidden\" name=\"telefono3_$n_c\" value=\"$telefono3\">
 <input type=\"hidden\" name=\"fax_$n_c\" value=\"$fax\">
 <input type=\"hidden\" name=\"cap_$n_c\" value=\"$cap\">
+<input type=\"hidden\" name=\"codice_fiscale_$n_c\" value=\"$codfiscale\">
+<input type=\"hidden\" name=\"partita_iva_$n_c\" value=\"$partitaiva\">
 <input type=\"hidden\" name=\"codice_lingua_$n_c\" value=\"$lingua_cli\">
 <input type=\"hidden\" name=\"email_$n_c\" value=\"$email_richiedente\">
 <input type=\"hidden\" name=\"data_inizio_$n_c\" value=\"".$inizioperiodo[$n_t]."\">
