@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2011 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2014 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -54,9 +54,9 @@ $priv_mod_doc = substr($priv_mod_pers,2,1);
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
 $attiva_contratti_consentiti = substr($contratti_consentiti,0,1);
 if ($attiva_contratti_consentiti == "s") {
-$contratti_consentiti = explode(",",substr($contratti_consentiti,2));
+$contratti_consentiti = explode(",",$contratti_consentiti);
 unset($contratti_consentiti_vett);
-for ($num1 = 0 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
+for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_consentiti[$num1]) $contratti_consentiti_vett[$contratti_consentiti[$num1]] = "SI";
 } # fine if ($attiva_contratti_consentiti == "s")
 } # fine else if (numlin_query($privilegi_annuali_utente) == 0)
 } # fine if ($id_utente != 1)
@@ -136,6 +136,7 @@ echo "".mex("Allegato eliminato",$pag).".<br>";
 } # fine if ($num_all)
 esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'opzeml'");
 } # fine if ($vecchio_formato == "contreml")
+if ($vecchio_formato == "contrtxt") esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'est_txt' ");
 if ($vecchio_formato == "contrhtm") esegui_query("delete from $tablecontratti where numero = '$num_contratto' and (tipo = 'headhtm' or tipo = 'foothtm') ");
 if ($formato == "contreml") {
 esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'dir'");
@@ -361,6 +362,28 @@ echo "".mex("Intestazione html cambiata",$pag).".<br>";
 } # fine if ($tipo_contratto == "contrhtm")
 } # fine if ($cambia_intestazione_pers)
 
+if ($cambia_estenstione_pers) {
+$tipo_contratto = esegui_query("select tipo from $tablecontratti where numero = '$num_contratto' and tipo $LIKE 'contr%'");
+$tipo_contratto = risul_query($tipo_contratto,0,'tipo');
+if ($tipo_contratto == "contrtxt") {
+if (@get_magic_quotes_gpc()) $estensione_pers_txt = stripslashes($estensione_pers_txt);
+$estensione_pers_txt = strtolower($estensione_pers_txt);
+if (preg_replace("/[a-z]/","",$estensione_pers_txt) != "" or strlen($estensione_pers_txt) > 10 or strlen($estensione_pers_txt) < 2) $estensione_pers_txt = "";
+$estensione_txt = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'est_txt'");
+if (numlin_query($estensione_txt) == 1) $estensione_txt = risul_query($estensione_txt,0,'testo');
+else $estensione_txt = "";
+if (($tipo_estensione_txt == "pers" and $estensione_pers_txt and $estensione_txt != $estensione_pers_txt) or ($tipo_estensione_txt == "predef" and $estensione_txt)) {
+$mostra_form_iniziale = "NO";
+if ($tipo_estensione_txt == "predef") esegui_query("delete from $tablecontratti where numero = '$num_contratto' and tipo = 'est_txt' ");
+else {
+if (!$estensione_txt) esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','est_txt','$estensione_pers_txt') ");
+else esegui_query("update $tablecontratti set testo = '$estensione_pers_txt' where numero = '$num_contratto' and tipo = 'est_txt'");
+} # fine else if ($tipo_estensione_txt == "predef")
+echo "".mex("Estensione cambiata",$pag).".<br>";
+} # fine if (($tipo_estensione_txt == "pers" and $estensione_pers_txt and...
+} # fine if ($tipo_contratto == "contrtxt")
+} # fine if ($cambia_estenstione_pers)
+
 if ($cambia_oggetto) {
 if (@get_magic_quotes_gpc()) $nuovo_oggetto = stripslashes($nuovo_oggetto);
 if (strlen($nuovo_oggetto) > 120) $nuovo_oggetto = substr($nuovo_oggetto,0,120);
@@ -566,6 +589,7 @@ if ($apertura) {
 if ($apertura == "r" and $livello != 0 and ($livello != 1 or ($tipo_livello[1] != "r4" and $tipo_livello[1] != "r6") or $tipo_livello[0] == "r")) $errore = "SI";
 if (($apertura == "r2" or $apertura == "r3" or $apertura == "r5") and $tipo_livello[$livello] != "r") $errore = "SI";
 if (($apertura == "r4" or $apertura == "r6") and $tipo_livello[$livello] != "r" and $livello != 0 and ($livello != 1 or ($tipo_livello[1] != "r4" and $tipo_livello[1] != "r6") or $tipo_livello[0] == "r")) $errore = "SI";
+if ($apertura == "r6" and $tipo_livello[1] == "r6") $errore = "SI";
 $livello++;
 $tipo_livello[$livello] = $apertura;
 } # fine ($apertura)
@@ -947,6 +971,39 @@ $contr_foot = risul_query($contr_foot,0,'testo');
 } # fine if ($tipo_contratto == "htm")
 
 
+if ($tipo_contratto == "txt") {
+$estensione_txt = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'est_txt'");
+if (numlin_query($estensione_txt) == 1) {
+$checked_predef = "";
+$checked_pers = " checked";
+$estensione_pers_txt = risul_query($estensione_txt,0,'testo');
+} # fine if (numlin_query($estensione_txt) == 1)
+else {
+$checked_predef = " checked";
+$checked_pers = "";
+$estensione_pers_txt = "txt";
+} # fine else if (numlin_query($estensione_txt) == 1)
+echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"$pag\"><div>
+<input type=\"hidden\" name=\"anno\" value=\"$anno\">
+<input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
+<input type=\"hidden\" name=\"num_contratto\" value=\"$num_contratto\">
+<input type=\"hidden\" name=\"cambia_qualcosa\" value=\"SI\">
+<table cellspacing=0 cellpadding=0 style=\"line-height: 1;\"><tr><td style=\"vertical-align: top;\">
+".mex("Estensione con cui vedere e scaricare il documento",$pag).": </td>
+<td><label><input type=\"radio\" name=\"tipo_estensione_txt\" value=\"predef\"$checked_predef>".mex("predefinita",$pag).": .txt</label><br>
+<label><input type=\"radio\" name=\"tipo_estensione_txt\" id=\"te_pers\" value=\"pers\"$checked_pers>".mex("personalizzata",$pag).":
+ .</label><input type=\"text\" name=\"estensione_pers_txt\" size=\"8\" maxlength=\"10\" value=\"$estensione_pers_txt\" onclick=\"document.getElementById('te_pers').checked='1'\"><br>
+<input class=\"sbutton\" type=\"submit\" name=\"cambia_estenstione_pers\" value=\"".mex("Cambia",$pag)."\">
+</td></tr></table>
+</div></form><br>";
+if ($checked) {
+$contr_head = risul_query($intestazione_html,0,'testo');
+$contr_foot = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'foothtm'");
+$contr_foot = risul_query($contr_foot,0,'testo');
+} # fine if ($checked)
+} # fine if ($tipo_contratto == "txt")
+
+
 if ($tipo_contratto == "eml") {
 $oggetto = esegui_query("select * from $tablecontratti where numero = '$num_contratto' and tipo = 'oggetto'");
 $oggetto = risul_query($oggetto,0,'testo');
@@ -1131,12 +1188,19 @@ $linea_mod = "<tr><td><a name=\"contr_txtbox".$lingue[$num_lingua]."\"></a>
 ".mex("Variabili",$pag).":
  <select name=\"var_agg\">";
 
+$campi_pers_comm = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'campi_pers_comm' and idutente = '$id_utente'");
+if (numlin_query($campi_pers_comm) == 1) {
+$campi_pers_comm = explode(">",risul_query($campi_pers_comm,0,'valpersonalizza'));
+$num_commenti_pers = count($campi_pers_comm);
+} # fine if (numlin_query($campi_pers_comm) == 1)
+else $num_commenti_pers = 0;
 $campi_pers_cliente = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'campi_pers_cliente' and idutente = '$id_utente' ");
 if (numlin_query($campi_pers_cliente)) {
 $campi_pers_cliente = explode(">",risul_query($campi_pers_cliente,0,'valpersonalizza'));
 $num_campi_pers_cliente = count($campi_pers_cliente);
 } # fine if (numlin_query($campi_pers_cliente))
 else $num_campi_pers_cliente = 0;
+$commento_personalizzato_ = mex2("commento_personalizzato")."_";
 $campo_personalizzato_ = mex2("campo_personalizzato")."_";
 include("./includes/variabili_contratto.php");
 $num_var_predef--;
