@@ -392,32 +392,6 @@ elem_id.blur();
 } // fine function blur_elem
 
 
-function seleziona_icona_tab () {
-var form_vtab = document.getElementById('vtab');
-var sel = form_vtab.getElementsByTagName('select');
-sel = sel[0].options[sel[0].selectedIndex].value;
-var el_vtab = form_vtab.getElementsByTagName('button');
-el_vtab = el_vtab[0].getElementsByTagName('div');
-if (sel == 'prenotazioni') el_vtab[0].style.backgroundImage = "url('./img/reservations.png')";
-if (sel == 'costi') el_vtab[0].style.backgroundImage = "url('./img/expinc.png')";
-if (sel == 'periodi') el_vtab[0].style.backgroundImage = "url('./img/rates.png')";
-if (sel == 'clienti') el_vtab[0].style.backgroundImage = "url('./img/client.png')";
-if (sel == 'regole') el_vtab[0].style.backgroundImage = "url('./img/rules.png')";
-if (sel == 'appartamenti') el_vtab[0].style.backgroundImage = "url('./img/rooms.png')";
-if (sel == 'inventario') el_vtab[0].style.backgroundImage = "url('./img/inventory.png')";
-if (sel == 'documenti') el_vtab[0].style.backgroundImage = "url('./img/documents.png')";
-if (sel == 'statistiche') el_vtab[0].style.backgroundImage = "url('./img/statistics.png')";
-} // fine function seleziona_icona_tab
-
-
-function attiva_seleziona_icona_tab () {
-seleziona_icona_tab();
-var form_vtab = document.getElementById('vtab');
-var select_vtab = form_vtab.getElementsByTagName('select');
-select_vtab[0].onchange = new Function("seleziona_icona_tab()");
-} // fine function attiva_seleziona_icona_tab
-
-
 function tab_in_container () {
 var tabs = document.getElementsByTagName('table');
 var maxtabwidth = tabs[0].offsetWidth;
